"""Generated model names for modelsdev provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 1021
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
ModelsDevModelId = Literal[
    "abacus:Qwen/qwen3-coder-480b-a35b-instruct",
    "abacus:claude-haiku-4-5-20251001",
    "abacus:claude-opus-4-1-20250805",
    "abacus:claude-opus-4-5-20251101",
    "abacus:claude-sonnet-4-5-20250929",
    "abacus:gemini-3-flash-preview",
    "abacus:gpt-5",
    "abacus:gpt-5-mini",
    "abacus:gpt-5-nano",
    "abacus:gpt-5.1",
    "abacus:gpt-5.1-chat-latest",
    "abacus:gpt-5.2",
    "abacus:gpt-5.2-chat-latest",
    "abacus:grok-4-0709",
    "abacus:grok-4-1-fast-non-reasoning",
    "abacus:grok-4-fast-non-reasoning",
    "abacus:grok-code-fast-1",
    "abacus:kimi-k2-turbo-preview",
    "abacus:openai/gpt-oss-120b",
    "abacus:zai-org/glm-4.5",
    "aihubmix:Kimi-K2-0905",
    "aihubmix:claude-haiku-4-5",
    "aihubmix:claude-opus-4-1",
    "aihubmix:claude-opus-4-5",
    "aihubmix:claude-sonnet-4-5",
    "aihubmix:coding-glm-4.7-free",
    "aihubmix:coding-minimax-m2.1-free",
    "aihubmix:deepseek-v3.2",
    "aihubmix:deepseek-v3.2-fast",
    "aihubmix:deepseek-v3.2-speciale",
    "aihubmix:deepseek-v3.2-think",
    "aihubmix:gemini-2.5-flash",
    "aihubmix:gemini-2.5-pro",
    "aihubmix:gemini-3-pro-preview",
    "aihubmix:glm-4.7",
    "aihubmix:gpt-5",
    "aihubmix:gpt-5-codex",
    "aihubmix:gpt-5-mini",
    "aihubmix:gpt-5-nano",
    "aihubmix:gpt-5-pro",
    "aihubmix:gpt-5.1",
    "aihubmix:gpt-5.1-codex",
    "aihubmix:gpt-5.1-codex-max",
    "aihubmix:gpt-5.1-codex-mini",
    "aihubmix:gpt-5.2",
    "aihubmix:minimax-m2.1",
    "aihubmix:o4-mini",
    "aihubmix:qwen3-235b-a22b-instruct-2507",
    "aihubmix:qwen3-235b-a22b-thinking-2507",
    "aihubmix:qwen3-coder-480b-a35b-instruct",
    "alibaba-cn:qwen-deep-research",
    "alibaba-cn:qwen-doc-turbo",
    "alibaba-cn:qwen-flash",
    "alibaba-cn:qwen-mt-plus",
    "alibaba-cn:qwen-mt-turbo",
    "alibaba-cn:qwen-plus-character",
    "alibaba-cn:qwen2-5-14b-instruct",
    "alibaba-cn:qwen2-5-32b-instruct",
    "alibaba-cn:qwen2-5-72b-instruct",
    "alibaba-cn:qwen2-5-7b-instruct",
    "alibaba-cn:qwen2-5-coder-32b-instruct",
    "alibaba-cn:qwen2-5-coder-7b-instruct",
    "alibaba-cn:qwen2-5-math-72b-instruct",
    "alibaba-cn:qwen2-5-math-7b-instruct",
    "alibaba-cn:qwen2-5-omni-7b",
    "alibaba-cn:qwen2-5-vl-72b-instruct",
    "alibaba-cn:qwen2-5-vl-7b-instruct",
    "alibaba-cn:qwen3-14b",
    "alibaba-cn:qwen3-235b-a22b",
    "alibaba-cn:qwen3-32b",
    "alibaba-cn:qwen3-8b",
    "alibaba-cn:qwen3-asr-flash",
    "alibaba-cn:qwen3-coder-30b-a3b-instruct",
    "alibaba-cn:qwen3-coder-480b-a35b-instruct",
    "alibaba-cn:qwen3-coder-flash",
    "alibaba-cn:qwen3-coder-plus",
    "alibaba-cn:qwen3-max",
    "alibaba-cn:qwen3-next-80b-a3b-instruct",
    "alibaba-cn:qwen3-next-80b-a3b-thinking",
    "alibaba-cn:qwen3-omni-flash",
    "alibaba-cn:qwen3-omni-flash-realtime",
    "alibaba-cn:qwen3-vl-235b-a22b",
    "alibaba-cn:qwen3-vl-30b-a3b",
    "alibaba-cn:qwen3-vl-plus",
    "alibaba-cn:qwq-32b",
    "alibaba-cn:tongyi-intent-detect-v3",
    "alibaba:qwen-flash",
    "alibaba:qwen-mt-plus",
    "alibaba:qwen-mt-turbo",
    "alibaba:qwen-plus-character-ja",
    "alibaba:qwen2-5-14b-instruct",
    "alibaba:qwen2-5-32b-instruct",
    "alibaba:qwen2-5-72b-instruct",
    "alibaba:qwen2-5-7b-instruct",
    "alibaba:qwen2-5-omni-7b",
    "alibaba:qwen2-5-vl-72b-instruct",
    "alibaba:qwen2-5-vl-7b-instruct",
    "alibaba:qwen3-14b",
    "alibaba:qwen3-235b-a22b",
    "alibaba:qwen3-32b",
    "alibaba:qwen3-8b",
    "alibaba:qwen3-asr-flash",
    "alibaba:qwen3-coder-30b-a3b-instruct",
    "alibaba:qwen3-coder-480b-a35b-instruct",
    "alibaba:qwen3-coder-flash",
    "alibaba:qwen3-coder-plus",
    "alibaba:qwen3-livetranslate-flash-realtime",
    "alibaba:qwen3-max",
    "alibaba:qwen3-next-80b-a3b-instruct",
    "alibaba:qwen3-next-80b-a3b-thinking",
    "alibaba:qwen3-omni-flash",
    "alibaba:qwen3-omni-flash-realtime",
    "alibaba:qwen3-vl-235b-a22b",
    "alibaba:qwen3-vl-30b-a3b",
    "alibaba:qwen3-vl-plus",
    "amazon-bedrock:anthropic.claude-haiku-4-5-20251001-v1:0",
    "amazon-bedrock:anthropic.claude-opus-4-1-20250805-v1:0",
    "amazon-bedrock:anthropic.claude-opus-4-5-20251101-v1:0",
    "amazon-bedrock:anthropic.claude-sonnet-4-5-20250929-v1:0",
    "amazon-bedrock:deepseek.v3-v1:0",
    "amazon-bedrock:global.anthropic.claude-opus-4-5-20251101-v1:0",
    "amazon-bedrock:google.gemma-3-27b-it",
    "amazon-bedrock:minimax.minimax-m2",
    "amazon-bedrock:moonshot.kimi-k2-thinking",
    "amazon-bedrock:qwen.qwen3-235b-a22b-2507-v1:0",
    "amazon-bedrock:qwen.qwen3-32b-v1:0",
    "amazon-bedrock:qwen.qwen3-coder-30b-a3b-v1:0",
    "amazon-bedrock:qwen.qwen3-coder-480b-a35b-v1:0",
    "amazon-bedrock:qwen.qwen3-next-80b-a3b",
    "amazon-bedrock:qwen.qwen3-vl-235b-a22b",
    "anthropic:claude-haiku-4-5",
    "anthropic:claude-haiku-4-5-20251001",
    "anthropic:claude-opus-4-1",
    "anthropic:claude-opus-4-1-20250805",
    "anthropic:claude-opus-4-5",
    "anthropic:claude-opus-4-5-20251101",
    "anthropic:claude-sonnet-4-5",
    "anthropic:claude-sonnet-4-5-20250929",
    "azure-cognitive-services:claude-haiku-4-5",
    "azure-cognitive-services:claude-opus-4-1",
    "azure-cognitive-services:claude-opus-4-5",
    "azure-cognitive-services:claude-sonnet-4-5",
    "azure-cognitive-services:deepseek-v3.1",
    "azure-cognitive-services:deepseek-v3.2",
    "azure-cognitive-services:deepseek-v3.2-speciale",
    "azure-cognitive-services:gpt-5",
    "azure-cognitive-services:gpt-5-chat",
    "azure-cognitive-services:gpt-5-codex",
    "azure-cognitive-services:gpt-5-mini",
    "azure-cognitive-services:gpt-5-nano",
    "azure-cognitive-services:gpt-5-pro",
    "azure-cognitive-services:gpt-5.1",
    "azure-cognitive-services:gpt-5.1-chat",
    "azure-cognitive-services:gpt-5.1-codex",
    "azure-cognitive-services:gpt-5.1-codex-mini",
    "azure-cognitive-services:gpt-5.2-chat",
    "azure-cognitive-services:gpt-5.2-codex",
    "azure-cognitive-services:grok-4",
    "azure-cognitive-services:grok-4-fast-non-reasoning",
    "azure-cognitive-services:grok-4-fast-reasoning",
    "azure-cognitive-services:grok-code-fast-1",
    "azure-cognitive-services:kimi-k2-thinking",
    "azure:claude-haiku-4-5",
    "azure:claude-opus-4-1",
    "azure:claude-opus-4-5",
    "azure:claude-sonnet-4-5",
    "azure:deepseek-v3.1",
    "azure:deepseek-v3.2",
    "azure:deepseek-v3.2-speciale",
    "azure:gpt-5",
    "azure:gpt-5-chat",
    "azure:gpt-5-codex",
    "azure:gpt-5-mini",
    "azure:gpt-5-nano",
    "azure:gpt-5-pro",
    "azure:gpt-5.1",
    "azure:gpt-5.1-chat",
    "azure:gpt-5.1-codex",
    "azure:gpt-5.1-codex-max",
    "azure:gpt-5.1-codex-mini",
    "azure:gpt-5.2",
    "azure:gpt-5.2-chat",
    "azure:gpt-5.2-codex",
    "azure:grok-4",
    "azure:grok-4-fast-non-reasoning",
    "azure:grok-4-fast-reasoning",
    "azure:grok-code-fast-1",
    "azure:kimi-k2-thinking",
    "bailing:Ling-1T",
    "bailing:Ring-1T",
    "baseten:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "baseten:deepseek-ai/DeepSeek-V3.2",
    "baseten:moonshotai/Kimi-K2-Instruct-0905",
    "baseten:moonshotai/Kimi-K2-Thinking",
    "baseten:zai-org/GLM-4.6",
    "baseten:zai-org/GLM-4.7",
    "cerebras:gpt-oss-120b",
    "cerebras:qwen-3-235b-a22b-instruct-2507",
    "cerebras:zai-glm-4.7",
    "chutes:MiniMaxAI/MiniMax-M2.1-TEE",
    "chutes:NousResearch/DeepHermes-3-Mistral-24B-Preview",
    "chutes:NousResearch/Hermes-4-14B",
    "chutes:NousResearch/Hermes-4-405B-FP8-TEE",
    "chutes:NousResearch/Hermes-4-70B",
    "chutes:NousResearch/Hermes-4.3-36B",
    "chutes:Qwen/Qwen2.5-72B-Instruct",
    "chutes:Qwen/Qwen2.5-Coder-32B-Instruct",
    "chutes:Qwen/Qwen2.5-VL-32B-Instruct",
    "chutes:Qwen/Qwen2.5-VL-72B-Instruct-TEE",
    "chutes:Qwen/Qwen3-14B",
    "chutes:Qwen/Qwen3-235B-A22B",
    "chutes:Qwen/Qwen3-235B-A22B-Instruct-2507-TEE",
    "chutes:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "chutes:Qwen/Qwen3-30B-A3B",
    "chutes:Qwen/Qwen3-30B-A3B-Instruct-2507",
    "chutes:Qwen/Qwen3-32B",
    "chutes:Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8-TEE",
    "chutes:Qwen/Qwen3-Next-80B-A3B-Instruct",
    "chutes:Qwen/Qwen3-VL-235B-A22B-Instruct",
    "chutes:Qwen/Qwen3Guard-Gen-0.6B",
    "chutes:XiaomiMiMo/MiMo-V2-Flash",
    "chutes:chutesai/Mistral-Small-3.1-24B-Instruct-2503",
    "chutes:chutesai/Mistral-Small-3.2-24B-Instruct-2506",
    "chutes:deepseek-ai/DeepSeek-R1-0528-TEE",
    "chutes:deepseek-ai/DeepSeek-R1-Distill-Llama-70B",
    "chutes:deepseek-ai/DeepSeek-R1-TEE",
    "chutes:deepseek-ai/DeepSeek-V3",
    "chutes:deepseek-ai/DeepSeek-V3-0324-TEE",
    "chutes:deepseek-ai/DeepSeek-V3.1-TEE",
    "chutes:deepseek-ai/DeepSeek-V3.1-Terminus-TEE",
    "chutes:deepseek-ai/DeepSeek-V3.2-Speciale-TEE",
    "chutes:deepseek-ai/DeepSeek-V3.2-TEE",
    "chutes:miromind-ai/MiroThinker-v1.5-235B",
    "chutes:mistralai/Devstral-2-123B-Instruct-2512",
    "chutes:mistralai/Devstral-2-123B-Instruct-2512-TEE",
    "chutes:moonshotai/Kimi-K2-Instruct-0905",
    "chutes:moonshotai/Kimi-K2-Thinking-TEE",
    "chutes:nvidia/NVIDIA-Nemotron-3-Nano-30B-A3B-BF16",
    "chutes:openai/gpt-oss-120b-TEE",
    "chutes:openai/gpt-oss-20b",
    "chutes:rednote-hilab/dots.ocr",
    "chutes:tngtech/DeepSeek-R1T-Chimera",
    "chutes:tngtech/DeepSeek-TNG-R1T2-Chimera",
    "chutes:tngtech/TNG-R1T-Chimera-TEE",
    "chutes:unsloth/Mistral-Nemo-Instruct-2407",
    "chutes:unsloth/Mistral-Small-24B-Instruct-2501",
    "chutes:unsloth/gemma-3-12b-it",
    "chutes:unsloth/gemma-3-27b-it",
    "chutes:unsloth/gemma-3-4b-it",
    "chutes:zai-org/GLM-4.5-Air",
    "chutes:zai-org/GLM-4.5-TEE",
    "chutes:zai-org/GLM-4.6-TEE",
    "chutes:zai-org/GLM-4.6V",
    "chutes:zai-org/GLM-4.7-TEE",
    "cloudflare-ai-gateway:anthropic/claude-haiku-4-5",
    "cloudflare-ai-gateway:anthropic/claude-opus-4-1",
    "cloudflare-ai-gateway:anthropic/claude-opus-4-5",
    "cloudflare-ai-gateway:anthropic/claude-sonnet-4-5",
    "cloudflare-ai-gateway:openai/gpt-5.1",
    "cloudflare-ai-gateway:openai/gpt-5.1-codex",
    "cloudflare-ai-gateway:openai/gpt-5.2",
    "cloudflare-ai-gateway:workers-ai/@cf/ai4bharat/indictrans2-en-indic-1B",
    "cloudflare-ai-gateway:workers-ai/@cf/aisingapore/gemma-sea-lion-v4-27b-it",
    "cloudflare-ai-gateway:workers-ai/@cf/deepgram/aura-2-en",
    "cloudflare-ai-gateway:workers-ai/@cf/deepgram/aura-2-es",
    "cloudflare-ai-gateway:workers-ai/@cf/deepgram/nova-3",
    "cloudflare-ai-gateway:workers-ai/@cf/ibm-granite/granite-4.0-h-micro",
    "cloudflare-ai-gateway:workers-ai/@cf/myshell-ai/melotts",
    "cloudflare-ai-gateway:workers-ai/@cf/openai/gpt-oss-120b",
    "cloudflare-ai-gateway:workers-ai/@cf/openai/gpt-oss-20b",
    "cloudflare-ai-gateway:workers-ai/@cf/pipecat-ai/smart-turn-v2",
    "cloudflare-ai-gateway:workers-ai/@cf/qwen/qwen3-30b-a3b-fp8",
    "cloudflare-workers-ai:aura-1",
    "cloudflare-workers-ai:gemma-sea-lion-v4-27b-it",
    "cloudflare-workers-ai:gpt-oss-120b",
    "cloudflare-workers-ai:gpt-oss-20b",
    "cloudflare-workers-ai:granite-4.0-h-micro",
    "cloudflare-workers-ai:lucid-origin",
    "cloudflare-workers-ai:phoenix-1.0",
    "cohere:command-a-reasoning-08-2025",
    "cohere:command-a-translate-08-2025",
    "cohere:command-a-vision-07-2025",
    "cortecs:claude-4-5-sonnet",
    "cortecs:devstral-2512",
    "cortecs:devstral-small-2512",
    "cortecs:gpt-oss-120b",
    "cortecs:intellect-3",
    "cortecs:kimi-k2-instruct",
    "cortecs:kimi-k2-thinking",
    "cortecs:qwen3-coder-480b-a35b-instruct",
    "cortecs:qwen3-next-80b-a3b-thinking",
    "deepinfra:MiniMaxAI/MiniMax-M2",
    "deepinfra:MiniMaxAI/MiniMax-M2.1",
    "deepinfra:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "deepinfra:Qwen/Qwen3-Coder-480B-A35B-Instruct-Turbo",
    "deepinfra:moonshotai/Kimi-K2-Instruct",
    "deepinfra:moonshotai/Kimi-K2-Thinking",
    "deepinfra:openai/gpt-oss-120b",
    "deepinfra:openai/gpt-oss-20b",
    "deepinfra:zai-org/GLM-4.5",
    "deepinfra:zai-org/GLM-4.7",
    "fastrouter:anthropic/claude-opus-4.1",
    "fastrouter:moonshotai/kimi-k2",
    "fastrouter:openai/gpt-5",
    "fastrouter:openai/gpt-5-mini",
    "fastrouter:openai/gpt-5-nano",
    "fastrouter:openai/gpt-oss-120b",
    "fastrouter:openai/gpt-oss-20b",
    "fastrouter:qwen/qwen3-coder",
    "fastrouter:x-ai/grok-4",
    "fireworks-ai:accounts/fireworks/models/deepseek-v3p1",
    "fireworks-ai:accounts/fireworks/models/deepseek-v3p2",
    "fireworks-ai:accounts/fireworks/models/glm-4p5",
    "fireworks-ai:accounts/fireworks/models/glm-4p5-air",
    "fireworks-ai:accounts/fireworks/models/glm-4p6",
    "fireworks-ai:accounts/fireworks/models/glm-4p7",
    "fireworks-ai:accounts/fireworks/models/gpt-oss-120b",
    "fireworks-ai:accounts/fireworks/models/gpt-oss-20b",
    "fireworks-ai:accounts/fireworks/models/kimi-k2-instruct",
    "fireworks-ai:accounts/fireworks/models/kimi-k2-thinking",
    "fireworks-ai:accounts/fireworks/models/minimax-m2",
    "fireworks-ai:accounts/fireworks/models/minimax-m2p1",
    "fireworks-ai:accounts/fireworks/models/qwen3-coder-480b-a35b-instruct",
    "firmware:claude-haiku-4-5-20251001",
    "firmware:claude-opus-4-5",
    "firmware:claude-sonnet-4-5-20250929",
    "firmware:gemini-2.5-flash",
    "firmware:gemini-3-flash-preview",
    "firmware:gemini-3-pro-preview",
    "firmware:gpt-5",
    "firmware:gpt-5-mini",
    "firmware:gpt-5-nano",
    "firmware:gpt-5.2",
    "firmware:grok-4-fast-non-reasoning",
    "firmware:grok-4-fast-reasoning",
    "firmware:grok-code-fast-1",
    "friendli:LGAI-EXAONE/EXAONE-4.0.1-32B",
    "friendli:LGAI-EXAONE/K-EXAONE-236B-A23B",
    "friendli:Qwen/Qwen3-235B-A22B-Instruct-2507",
    "friendli:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "friendli:zai-org/GLM-4.6",
    "github-copilot:claude-haiku-4.5",
    "github-copilot:claude-opus-4.5",
    "github-copilot:claude-opus-41",
    "github-copilot:claude-sonnet-4.5",
    "github-copilot:gemini-3-flash-preview",
    "github-copilot:gemini-3-pro-preview",
    "github-copilot:gpt-5",
    "github-copilot:gpt-5-codex",
    "github-copilot:gpt-5-mini",
    "github-copilot:gpt-5.1",
    "github-copilot:gpt-5.1-codex",
    "github-copilot:gpt-5.1-codex-max",
    "github-copilot:gpt-5.1-codex-mini",
    "github-copilot:gpt-5.2",
    "github-copilot:gpt-5.2-codex",
    "github-copilot:grok-code-fast-1",
    "gitlab:duo-chat-haiku-4-5",
    "gitlab:duo-chat-opus-4-5",
    "gitlab:duo-chat-sonnet-4-5",
    "google-vertex-anthropic:claude-haiku-4-5@20251001",
    "google-vertex-anthropic:claude-opus-4-1@20250805",
    "google-vertex-anthropic:claude-opus-4-5@20251101",
    "google-vertex-anthropic:claude-sonnet-4-5@20250929",
    "google-vertex:gemini-2.5-flash-lite-preview-09-2025",
    "google-vertex:gemini-2.5-flash-preview-09-2025",
    "google-vertex:gemini-3-flash-preview",
    "google-vertex:gemini-3-pro-preview",
    "google-vertex:gemini-flash-latest",
    "google-vertex:gemini-flash-lite-latest",
    "google-vertex:openai/gpt-oss-120b-maas",
    "google-vertex:openai/gpt-oss-20b-maas",
    "google:gemini-2.5-flash-image",
    "google:gemini-2.5-flash-image-preview",
    "google:gemini-2.5-flash-lite-preview-09-2025",
    "google:gemini-2.5-flash-preview-09-2025",
    "google:gemini-3-flash-preview",
    "google:gemini-3-pro-preview",
    "google:gemini-flash-latest",
    "google:gemini-flash-lite-latest",
    "google:gemini-live-2.5-flash",
    "groq:moonshotai/kimi-k2-instruct",
    "groq:moonshotai/kimi-k2-instruct-0905",
    "groq:openai/gpt-oss-120b",
    "groq:openai/gpt-oss-20b",
    "helicone:claude-4.5-haiku",
    "helicone:claude-4.5-opus",
    "helicone:claude-4.5-sonnet",
    "helicone:claude-haiku-4-5-20251001",
    "helicone:claude-opus-4-1",
    "helicone:claude-opus-4-1-20250805",
    "helicone:claude-sonnet-4-5-20250929",
    "helicone:deepseek-v3.1-terminus",
    "helicone:deepseek-v3.2",
    "helicone:gemini-2.5-flash-lite",
    "helicone:gemini-3-pro-preview",
    "helicone:grok-4-1-fast-non-reasoning",
    "helicone:grok-4-1-fast-reasoning",
    "helicone:grok-4-fast-non-reasoning",
    "helicone:grok-4-fast-reasoning",
    "helicone:kimi-k2-0905",
    "helicone:kimi-k2-thinking",
    "helicone:qwen3-235b-a22b-thinking",
    "helicone:qwen3-coder",
    "helicone:qwen3-coder-30b-a3b-instruct",
    "helicone:qwen3-vl-235b-a22b-instruct",
    "huggingface:MiniMaxAI/MiniMax-M2.1",
    "huggingface:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "huggingface:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "huggingface:Qwen/Qwen3-Next-80B-A3B-Instruct",
    "huggingface:Qwen/Qwen3-Next-80B-A3B-Thinking",
    "huggingface:XiaomiMiMo/MiMo-V2-Flash",
    "huggingface:deepseek-ai/DeepSeek-V3.2",
    "huggingface:moonshotai/Kimi-K2-Instruct",
    "huggingface:moonshotai/Kimi-K2-Instruct-0905",
    "huggingface:moonshotai/Kimi-K2-Thinking",
    "huggingface:zai-org/GLM-4.7",
    "iflowcn:kimi-k2-0905",
    "kimi-for-coding:kimi-k2-thinking",
    "lmstudio:openai/gpt-oss-20b",
    "lmstudio:qwen/qwen3-30b-a3b-2507",
    "lmstudio:qwen/qwen3-coder-30b",
    "lucidquery:lucidquery-nexus-coder",
    "minimax-cn:MiniMax-M2",
    "minimax-cn:MiniMax-M2.1",
    "minimax:MiniMax-M2",
    "minimax:MiniMax-M2.1",
    "mistral:devstral-2512",
    "mistral:devstral-medium-2507",
    "mistral:devstral-medium-latest",
    "mistral:devstral-small-2507",
    "mistral:labs-devstral-small-2512",
    "mistral:mistral-medium-2508",
    "modelscope:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "modelscope:Qwen/Qwen3-30B-A3B-Instruct-2507",
    "modelscope:Qwen/Qwen3-30B-A3B-Thinking-2507",
    "modelscope:Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "modelscope:ZhipuAI/GLM-4.5",
    "modelscope:ZhipuAI/GLM-4.6",
    "moonshotai-cn:kimi-k2-0711-preview",
    "moonshotai-cn:kimi-k2-0905-preview",
    "moonshotai-cn:kimi-k2-thinking",
    "moonshotai-cn:kimi-k2-thinking-turbo",
    "moonshotai-cn:kimi-k2-turbo-preview",
    "moonshotai:kimi-k2-0711-preview",
    "moonshotai:kimi-k2-0905-preview",
    "moonshotai:kimi-k2-thinking",
    "moonshotai:kimi-k2-thinking-turbo",
    "moonshotai:kimi-k2-turbo-preview",
    "nano-gpt:deepseek/deepseek-v3.2:thinking",
    "nano-gpt:minimax/minimax-m2.1",
    "nano-gpt:mistralai/devstral-2-123b-instruct-2512",
    "nano-gpt:mistralai/ministral-14b-instruct-2512",
    "nano-gpt:mistralai/mistral-large-3-675b-instruct-2512",
    "nano-gpt:nvidia/llama-3_3-nemotron-super-49b-v1_5",
    "nano-gpt:zai-org/glm-4.5-air",
    "nano-gpt:zai-org/glm-4.7",
    "nebius:qwen/qwen3-235b-a22b-instruct-2507",
    "nebius:qwen/qwen3-235b-a22b-thinking-2507",
    "nebius:qwen/qwen3-coder-480b-a35b-instruct",
    "novita-ai:baichuan/baichuan-m2-32b",
    "novita-ai:baidu/ernie-4.5-21B-a3b-thinking",
    "novita-ai:baidu/ernie-4.5-vl-28b-a3b-thinking",
    "novita-ai:deepseek/deepseek-ocr",
    "novita-ai:deepseek/deepseek-v3.1",
    "novita-ai:deepseek/deepseek-v3.1-terminus",
    "novita-ai:deepseek/deepseek-v3.2",
    "novita-ai:deepseek/deepseek-v3.2-exp",
    "novita-ai:kwaipilot/kat-coder",
    "novita-ai:kwaipilot/kat-coder-pro",
    "novita-ai:minimax/minimax-m2",
    "novita-ai:minimax/minimax-m2.1",
    "novita-ai:moonshotai/kimi-k2-0905",
    "novita-ai:moonshotai/kimi-k2-instruct",
    "novita-ai:moonshotai/kimi-k2-thinking",
    "novita-ai:openai/gpt-oss-120b",
    "novita-ai:openai/gpt-oss-20b",
    "novita-ai:paddlepaddle/paddleocr-vl",
    "novita-ai:qwen/qwen-mt-plus",
    "novita-ai:qwen/qwen3-235b-a22b-instruct-2507",
    "novita-ai:qwen/qwen3-235b-a22b-thinking-2507",
    "novita-ai:qwen/qwen3-coder-30b-a3b-instruct",
    "novita-ai:qwen/qwen3-coder-480b-a35b-instruct",
    "novita-ai:qwen/qwen3-max",
    "novita-ai:qwen/qwen3-next-80b-a3b-instruct",
    "novita-ai:qwen/qwen3-next-80b-a3b-thinking",
    "novita-ai:qwen/qwen3-omni-30b-a3b-instruct",
    "novita-ai:qwen/qwen3-omni-30b-a3b-thinking",
    "novita-ai:qwen/qwen3-vl-235b-a22b-instruct",
    "novita-ai:qwen/qwen3-vl-235b-a22b-thinking",
    "novita-ai:qwen/qwen3-vl-30b-a3b-instruct",
    "novita-ai:qwen/qwen3-vl-30b-a3b-thinking",
    "novita-ai:qwen/qwen3-vl-8b-instruct",
    "novita-ai:skywork/r1v4-lite",
    "novita-ai:xiaomimimo/mimo-v2-flash",
    "novita-ai:zai-org/autoglm-phone-9b-multilingual",
    "novita-ai:zai-org/glm-4.5",
    "novita-ai:zai-org/glm-4.5-air",
    "novita-ai:zai-org/glm-4.5v",
    "novita-ai:zai-org/glm-4.6",
    "novita-ai:zai-org/glm-4.6v",
    "novita-ai:zai-org/glm-4.7",
    "nvidia:deepseek-ai/deepseek-v3.1",
    "nvidia:deepseek-ai/deepseek-v3.1-terminus",
    "nvidia:minimaxai/minimax-m2",
    "nvidia:mistralai/devstral-2-123b-instruct-2512",
    "nvidia:mistralai/ministral-14b-instruct-2512",
    "nvidia:mistralai/mistral-large-3-675b-instruct-2512",
    "nvidia:moonshotai/kimi-k2-instruct-0905",
    "nvidia:moonshotai/kimi-k2-thinking",
    "nvidia:nvidia/nemotron-3-nano-30b-a3b",
    "nvidia:nvidia/nvidia-nemotron-nano-9b-v2",
    "nvidia:openai/gpt-oss-120b",
    "nvidia:qwen/qwen3-coder-480b-a35b-instruct",
    "ollama-cloud:cogito-2.1:671b-cloud",
    "ollama-cloud:deepseek-v3.1:671b-cloud",
    "ollama-cloud:gemini-3-pro-preview:latest",
    "ollama-cloud:glm-4.6:cloud",
    "ollama-cloud:gpt-oss:120b-cloud",
    "ollama-cloud:gpt-oss:20b-cloud",
    "ollama-cloud:kimi-k2-thinking:cloud",
    "ollama-cloud:kimi-k2:1t-cloud",
    "ollama-cloud:minimax-m2:cloud",
    "ollama-cloud:qwen3-coder:480b-cloud",
    "ollama-cloud:qwen3-vl-235b-cloud",
    "ollama-cloud:qwen3-vl-235b-instruct-cloud",
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:gpt-5.1-chat-latest",
    "openai:gpt-5.1-codex",
    "openai:gpt-5.1-codex-max",
    "openai:gpt-5.1-codex-mini",
    "openai:gpt-5.2",
    "openai:gpt-5.2-chat-latest",
    "openai:gpt-5.2-codex",
    "openai:gpt-5.2-pro",
    "opencode:alpha-glm-4.7",
    "opencode:big-pickle",
    "opencode:claude-haiku-4-5",
    "opencode:claude-opus-4-1",
    "opencode:claude-opus-4-5",
    "opencode:claude-sonnet-4-5",
    "opencode:gemini-3-flash",
    "opencode:gemini-3-pro",
    "opencode:glm-4.6",
    "opencode:glm-4.7-free",
    "opencode:gpt-5",
    "opencode:gpt-5-codex",
    "opencode:gpt-5-nano",
    "opencode:gpt-5.1",
    "opencode:gpt-5.1-codex",
    "opencode:gpt-5.1-codex-max",
    "opencode:gpt-5.1-codex-mini",
    "opencode:gpt-5.2",
    "opencode:gpt-5.2-codex",
    "opencode:grok-code",
    "opencode:kimi-k2",
    "opencode:kimi-k2-thinking",
    "opencode:minimax-m2.1-free",
    "opencode:qwen3-coder",
    "openrouter:anthropic/claude-haiku-4.5",
    "openrouter:anthropic/claude-opus-4.1",
    "openrouter:anthropic/claude-opus-4.5",
    "openrouter:anthropic/claude-sonnet-4.5",
    "openrouter:deepseek/deepseek-chat-v3.1",
    "openrouter:deepseek/deepseek-v3.1-terminus",
    "openrouter:deepseek/deepseek-v3.1-terminus:exacto",
    "openrouter:deepseek/deepseek-v3.2",
    "openrouter:deepseek/deepseek-v3.2-speciale",
    "openrouter:google/gemini-2.5-flash",
    "openrouter:google/gemini-2.5-flash-lite-preview-09-2025",
    "openrouter:google/gemini-2.5-flash-preview-09-2025",
    "openrouter:google/gemini-3-flash-preview",
    "openrouter:google/gemini-3-pro-preview",
    "openrouter:kwaipilot/kat-coder-pro:free",
    "openrouter:minimax/minimax-m2",
    "openrouter:minimax/minimax-m2.1",
    "openrouter:mistralai/codestral-2508",
    "openrouter:mistralai/devstral-2512",
    "openrouter:mistralai/devstral-2512:free",
    "openrouter:mistralai/devstral-medium-2507",
    "openrouter:mistralai/devstral-small-2507",
    "openrouter:mistralai/mistral-medium-3.1",
    "openrouter:moonshotai/kimi-k2",
    "openrouter:moonshotai/kimi-k2-0905",
    "openrouter:moonshotai/kimi-k2-0905:exacto",
    "openrouter:moonshotai/kimi-k2-thinking",
    "openrouter:moonshotai/kimi-k2:free",
    "openrouter:nousresearch/hermes-4-405b",
    "openrouter:nousresearch/hermes-4-70b",
    "openrouter:nvidia/nemotron-nano-9b-v2",
    "openrouter:openai/gpt-5",
    "openrouter:openai/gpt-5-chat",
    "openrouter:openai/gpt-5-codex",
    "openrouter:openai/gpt-5-image",
    "openrouter:openai/gpt-5-mini",
    "openrouter:openai/gpt-5-nano",
    "openrouter:openai/gpt-5-pro",
    "openrouter:openai/gpt-5.1",
    "openrouter:openai/gpt-5.1-chat",
    "openrouter:openai/gpt-5.1-codex",
    "openrouter:openai/gpt-5.1-codex-mini",
    "openrouter:openai/gpt-5.2",
    "openrouter:openai/gpt-5.2-chat-latest",
    "openrouter:openai/gpt-5.2-codex",
    "openrouter:openai/gpt-5.2-pro",
    "openrouter:openai/gpt-oss-120b",
    "openrouter:openai/gpt-oss-120b:exacto",
    "openrouter:openai/gpt-oss-20b",
    "openrouter:openai/gpt-oss-safeguard-20b",
    "openrouter:openrouter/sherlock-dash-alpha",
    "openrouter:openrouter/sherlock-think-alpha",
    "openrouter:qwen/qwen3-235b-a22b-thinking-2507",
    "openrouter:qwen/qwen3-30b-a3b-instruct-2507",
    "openrouter:qwen/qwen3-30b-a3b-thinking-2507",
    "openrouter:qwen/qwen3-coder",
    "openrouter:qwen/qwen3-coder-30b-a3b-instruct",
    "openrouter:qwen/qwen3-coder-flash",
    "openrouter:qwen/qwen3-coder:exacto",
    "openrouter:qwen/qwen3-coder:free",
    "openrouter:qwen/qwen3-max",
    "openrouter:qwen/qwen3-next-80b-a3b-instruct",
    "openrouter:qwen/qwen3-next-80b-a3b-thinking",
    "openrouter:tngtech/deepseek-r1t2-chimera:free",
    "openrouter:x-ai/grok-4",
    "openrouter:x-ai/grok-4-fast",
    "openrouter:x-ai/grok-4.1-fast",
    "openrouter:x-ai/grok-code-fast-1",
    "openrouter:z-ai/glm-4.5",
    "openrouter:z-ai/glm-4.5-air",
    "openrouter:z-ai/glm-4.5-air:free",
    "openrouter:z-ai/glm-4.5v",
    "openrouter:z-ai/glm-4.6",
    "openrouter:z-ai/glm-4.6:exacto",
    "openrouter:z-ai/glm-4.7",
    "ovhcloud:gpt-oss-120b",
    "ovhcloud:gpt-oss-20b",
    "ovhcloud:mistral-small-3.2-24b-instruct-2506",
    "ovhcloud:qwen3-32b",
    "ovhcloud:qwen3-coder-30b-a3b-instruct",
    "poe:anthropic/claude-haiku-4.5",
    "poe:anthropic/claude-opus-4.1",
    "poe:anthropic/claude-opus-4.5",
    "poe:anthropic/claude-sonnet-4.5",
    "poe:cerebras/gpt-oss-120b-cs",
    "poe:cerebras/zai-glm-4.6-cs",
    "poe:elevenlabs/elevenlabs-music",
    "poe:google/gemini-3-flash",
    "poe:google/gemini-3-pro",
    "poe:google/gemini-deep-research",
    "poe:google/nano-banana",
    "poe:google/nano-banana-pro",
    "poe:google/veo-3-fast",
    "poe:google/veo-3.1",
    "poe:google/veo-3.1-fast",
    "poe:novita/glm-4.6",
    "poe:novita/glm-4.6v",
    "poe:novita/glm-4.7",
    "poe:novita/kat-coder-pro",
    "poe:novita/kimi-k2-thinking",
    "poe:novita/minimax-m2.1",
    "poe:openai/gpt-5",
    "poe:openai/gpt-5-chat",
    "poe:openai/gpt-5-codex",
    "poe:openai/gpt-5-nano",
    "poe:openai/gpt-5-pro",
    "poe:openai/gpt-5.1",
    "poe:openai/gpt-5.1-codex",
    "poe:openai/gpt-5.1-codex-max",
    "poe:openai/gpt-5.1-codex-mini",
    "poe:openai/gpt-5.1-instant",
    "poe:openai/gpt-5.2",
    "poe:openai/gpt-5.2-instant",
    "poe:openai/gpt-5.2-pro",
    "poe:openai/gpt-image-1-mini",
    "poe:openai/gpt-image-1.5",
    "poe:openai/sora-2",
    "poe:openai/sora-2-pro",
    "poe:poetools/claude-code",
    "poe:xai/grok-4",
    "poe:xai/grok-4-fast-non-reasoning",
    "poe:xai/grok-4-fast-reasoning",
    "poe:xai/grok-4.1-fast-non-reasoning",
    "poe:xai/grok-4.1-fast-reasoning",
    "poe:xai/grok-code-fast-1",
    "privatemode-ai:gpt-oss-120b",
    "privatemode-ai:qwen3-coder-30b-a3b",
    "requesty:anthropic/claude-haiku-4-5",
    "requesty:anthropic/claude-opus-4-1",
    "requesty:anthropic/claude-opus-4-5",
    "requesty:anthropic/claude-sonnet-4-5",
    "requesty:google/gemini-3-flash-preview",
    "requesty:google/gemini-3-pro-preview",
    "requesty:openai/gpt-5",
    "requesty:openai/gpt-5-mini",
    "requesty:openai/gpt-5-nano",
    "requesty:xai/grok-4",
    "requesty:xai/grok-4-fast",
    "sap-ai-core:anthropic--claude-4.5-haiku",
    "sap-ai-core:anthropic--claude-4.5-opus",
    "sap-ai-core:anthropic--claude-4.5-sonnet",
    "sap-ai-core:gpt-5",
    "sap-ai-core:gpt-5-mini",
    "sap-ai-core:gpt-5-nano",
    "scaleway:devstral-2-123b-instruct-2512",
    "scaleway:qwen3-coder-30b-a3b-instruct",
    "siliconflow-cn:ByteDance-Seed/Seed-OSS-36B-Instruct",
    "siliconflow-cn:Kwaipilot/KAT-Dev",
    "siliconflow-cn:MiniMaxAI/MiniMax-M2",
    "siliconflow-cn:Qwen/Qwen3-235B-A22B-Instruct-2507",
    "siliconflow-cn:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "siliconflow-cn:Qwen/Qwen3-30B-A3B-Instruct-2507",
    "siliconflow-cn:Qwen/Qwen3-30B-A3B-Thinking-2507",
    "siliconflow-cn:Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-Next-80B-A3B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-Next-80B-A3B-Thinking",
    "siliconflow-cn:Qwen/Qwen3-Omni-30B-A3B-Captioner",
    "siliconflow-cn:Qwen/Qwen3-Omni-30B-A3B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-Omni-30B-A3B-Thinking",
    "siliconflow-cn:Qwen/Qwen3-VL-235B-A22B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-VL-235B-A22B-Thinking",
    "siliconflow-cn:Qwen/Qwen3-VL-30B-A3B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-VL-30B-A3B-Thinking",
    "siliconflow-cn:Qwen/Qwen3-VL-32B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-VL-32B-Thinking",
    "siliconflow-cn:Qwen/Qwen3-VL-8B-Instruct",
    "siliconflow-cn:Qwen/Qwen3-VL-8B-Thinking",
    "siliconflow-cn:THUDM/GLM-4.1V-9B-Thinking",
    "siliconflow-cn:deepseek-ai/DeepSeek-V3.1-Terminus",
    "siliconflow-cn:deepseek-ai/DeepSeek-V3.2",
    "siliconflow-cn:inclusionAI/Ling-flash-2.0",
    "siliconflow-cn:inclusionAI/Ling-mini-2.0",
    "siliconflow-cn:inclusionAI/Ring-flash-2.0",
    "siliconflow-cn:moonshotai/Kimi-K2-Instruct",
    "siliconflow-cn:moonshotai/Kimi-K2-Instruct-0905",
    "siliconflow-cn:moonshotai/Kimi-K2-Thinking",
    "siliconflow-cn:openai/gpt-oss-120b",
    "siliconflow-cn:openai/gpt-oss-20b",
    "siliconflow-cn:stepfun-ai/step3",
    "siliconflow-cn:tencent/Hunyuan-MT-7B",
    "siliconflow-cn:zai-org/GLM-4.5",
    "siliconflow-cn:zai-org/GLM-4.5-Air",
    "siliconflow-cn:zai-org/GLM-4.5V",
    "siliconflow-cn:zai-org/GLM-4.6",
    "siliconflow-cn:zai-org/GLM-4.6V",
    "siliconflow:ByteDance-Seed/Seed-OSS-36B-Instruct",
    "siliconflow:MiniMaxAI/MiniMax-M2",
    "siliconflow:Qwen/Qwen3-235B-A22B-Instruct-2507",
    "siliconflow:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "siliconflow:Qwen/Qwen3-30B-A3B-Instruct-2507",
    "siliconflow:Qwen/Qwen3-30B-A3B-Thinking-2507",
    "siliconflow:Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "siliconflow:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "siliconflow:Qwen/Qwen3-Next-80B-A3B-Instruct",
    "siliconflow:Qwen/Qwen3-Next-80B-A3B-Thinking",
    "siliconflow:Qwen/Qwen3-Omni-30B-A3B-Captioner",
    "siliconflow:Qwen/Qwen3-Omni-30B-A3B-Instruct",
    "siliconflow:Qwen/Qwen3-Omni-30B-A3B-Thinking",
    "siliconflow:Qwen/Qwen3-VL-235B-A22B-Instruct",
    "siliconflow:Qwen/Qwen3-VL-235B-A22B-Thinking",
    "siliconflow:Qwen/Qwen3-VL-30B-A3B-Instruct",
    "siliconflow:Qwen/Qwen3-VL-30B-A3B-Thinking",
    "siliconflow:Qwen/Qwen3-VL-32B-Instruct",
    "siliconflow:Qwen/Qwen3-VL-32B-Thinking",
    "siliconflow:Qwen/Qwen3-VL-8B-Instruct",
    "siliconflow:Qwen/Qwen3-VL-8B-Thinking",
    "siliconflow:THUDM/GLM-4.1V-9B-Thinking",
    "siliconflow:deepseek-ai/DeepSeek-V3.1",
    "siliconflow:deepseek-ai/DeepSeek-V3.1-Terminus",
    "siliconflow:deepseek-ai/DeepSeek-V3.2",
    "siliconflow:deepseek-ai/DeepSeek-V3.2-Exp",
    "siliconflow:inclusionAI/Ling-flash-2.0",
    "siliconflow:inclusionAI/Ling-mini-2.0",
    "siliconflow:inclusionAI/Ring-flash-2.0",
    "siliconflow:moonshotai/Kimi-K2-Instruct",
    "siliconflow:moonshotai/Kimi-K2-Instruct-0905",
    "siliconflow:moonshotai/Kimi-K2-Thinking",
    "siliconflow:openai/gpt-oss-120b",
    "siliconflow:openai/gpt-oss-20b",
    "siliconflow:stepfun-ai/step3",
    "siliconflow:tencent/Hunyuan-MT-7B",
    "siliconflow:zai-org/GLM-4.5",
    "siliconflow:zai-org/GLM-4.5-Air",
    "siliconflow:zai-org/GLM-4.5V",
    "siliconflow:zai-org/GLM-4.6",
    "siliconflow:zai-org/GLM-4.6V",
    "siliconflow:zai-org/GLM-4.7",
    "submodel:Qwen/Qwen3-235B-A22B-Instruct-2507",
    "submodel:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "submodel:Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8",
    "submodel:deepseek-ai/DeepSeek-R1-0528",
    "submodel:deepseek-ai/DeepSeek-V3-0324",
    "submodel:deepseek-ai/DeepSeek-V3.1",
    "submodel:openai/gpt-oss-120b",
    "submodel:zai-org/GLM-4.5-Air",
    "submodel:zai-org/GLM-4.5-FP8",
    "synthetic:hf:MiniMaxAI/MiniMax-M2",
    "synthetic:hf:MiniMaxAI/MiniMax-M2.1",
    "synthetic:hf:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "synthetic:hf:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "synthetic:hf:deepseek-ai/DeepSeek-R1-0528",
    "synthetic:hf:deepseek-ai/DeepSeek-V3-0324",
    "synthetic:hf:deepseek-ai/DeepSeek-V3.1",
    "synthetic:hf:deepseek-ai/DeepSeek-V3.1-Terminus",
    "synthetic:hf:deepseek-ai/DeepSeek-V3.2",
    "synthetic:hf:moonshotai/Kimi-K2-Instruct-0905",
    "synthetic:hf:moonshotai/Kimi-K2-Thinking",
    "synthetic:hf:openai/gpt-oss-120b",
    "synthetic:hf:zai-org/GLM-4.5",
    "synthetic:hf:zai-org/GLM-4.6",
    "synthetic:hf:zai-org/GLM-4.7",
    "togetherai:Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8",
    "togetherai:deepseek-ai/DeepSeek-V3-1",
    "togetherai:essentialai/Rnj-1-Instruct",
    "togetherai:moonshotai/Kimi-K2-Instruct",
    "togetherai:moonshotai/Kimi-K2-Thinking",
    "togetherai:openai/gpt-oss-120b",
    "togetherai:zai-org/GLM-4.6",
    "upstage:solar-pro3",
    "venice:claude-opus-45",
    "venice:deepseek-v3.2",
    "venice:gemini-3-flash-preview",
    "venice:gemini-3-pro-preview",
    "venice:google-gemma-3-27b-it",
    "venice:grok-41-fast",
    "venice:grok-code-fast-1",
    "venice:hermes-3-llama-3.1-405b",
    "venice:kimi-k2-thinking",
    "venice:minimax-m21",
    "venice:openai-gpt-52",
    "venice:openai-gpt-oss-120b",
    "venice:zai-org-glm-4.6v",
    "venice:zai-org-glm-4.7",
    "vercel:alibaba/qwen-3-14b",
    "vercel:alibaba/qwen-3-235b",
    "vercel:alibaba/qwen-3-30b",
    "vercel:alibaba/qwen-3-32b",
    "vercel:alibaba/qwen3-235b-a22b-thinking",
    "vercel:alibaba/qwen3-coder",
    "vercel:alibaba/qwen3-coder-30b-a3b",
    "vercel:alibaba/qwen3-coder-plus",
    "vercel:alibaba/qwen3-max",
    "vercel:alibaba/qwen3-max-preview",
    "vercel:alibaba/qwen3-next-80b-a3b-instruct",
    "vercel:alibaba/qwen3-next-80b-a3b-thinking",
    "vercel:alibaba/qwen3-vl-instruct",
    "vercel:alibaba/qwen3-vl-thinking",
    "vercel:anthropic/claude-haiku-4.5",
    "vercel:anthropic/claude-opus-4.5",
    "vercel:anthropic/claude-sonnet-4.5",
    "vercel:arcee-ai/trinity-mini",
    "vercel:bfl/flux-kontext-max",
    "vercel:bfl/flux-kontext-pro",
    "vercel:bfl/flux-pro-1.0-fill",
    "vercel:bfl/flux-pro-1.1",
    "vercel:bfl/flux-pro-1.1-ultra",
    "vercel:bytedance/seed-1.6",
    "vercel:bytedance/seed-1.8",
    "vercel:deepseek/deepseek-v3.1",
    "vercel:deepseek/deepseek-v3.1-terminus",
    "vercel:deepseek/deepseek-v3.2",
    "vercel:deepseek/deepseek-v3.2-exp",
    "vercel:deepseek/deepseek-v3.2-thinking",
    "vercel:google/gemini-2.5-flash-lite-preview-09-2025",
    "vercel:google/gemini-2.5-flash-preview-09-2025",
    "vercel:google/gemini-3-flash",
    "vercel:google/gemini-3-pro-image",
    "vercel:google/gemini-3-pro-preview",
    "vercel:google/imagen-4.0-fast-generate-001",
    "vercel:kwaipilot/kat-coder-pro-v1",
    "vercel:meituan/longcat-flash-chat",
    "vercel:meituan/longcat-flash-thinking",
    "vercel:minimax/minimax-m2",
    "vercel:minimax/minimax-m2.1",
    "vercel:minimax/minimax-m2.1-lightning",
    "vercel:mistral/devstral-2",
    "vercel:mistral/ministral-14b",
    "vercel:mistral/mistral-large-3",
    "vercel:moonshotai/kimi-k2",
    "vercel:moonshotai/kimi-k2-0905",
    "vercel:moonshotai/kimi-k2-thinking",
    "vercel:moonshotai/kimi-k2-thinking-turbo",
    "vercel:moonshotai/kimi-k2-turbo",
    "vercel:nvidia/nemotron-3-nano-30b-a3b",
    "vercel:nvidia/nemotron-nano-12b-v2-vl",
    "vercel:nvidia/nemotron-nano-9b-v2",
    "vercel:openai/gpt-5",
    "vercel:openai/gpt-5-chat",
    "vercel:openai/gpt-5-codex",
    "vercel:openai/gpt-5-mini",
    "vercel:openai/gpt-5-nano",
    "vercel:openai/gpt-5-pro",
    "vercel:openai/gpt-5.1-codex",
    "vercel:openai/gpt-5.1-codex-max",
    "vercel:openai/gpt-5.1-instant",
    "vercel:openai/gpt-5.1-thinking",
    "vercel:openai/gpt-5.2",
    "vercel:openai/gpt-5.2-chat",
    "vercel:openai/gpt-5.2-codex",
    "vercel:openai/gpt-5.2-pro",
    "vercel:openai/gpt-oss-120b",
    "vercel:openai/gpt-oss-20b",
    "vercel:prime-intellect/intellect-3",
    "vercel:recraft/recraft-v2",
    "vercel:recraft/recraft-v3",
    "vercel:voyage/voyage-3-large",
    "vercel:voyage/voyage-code-2",
    "vercel:voyage/voyage-code-3",
    "vercel:voyage/voyage-finance-2",
    "vercel:voyage/voyage-law-2",
    "vercel:xai/grok-4",
    "vercel:xai/grok-4-fast-non-reasoning",
    "vercel:xai/grok-4-fast-reasoning",
    "vercel:xai/grok-4.1-fast-non-reasoning",
    "vercel:xai/grok-4.1-fast-reasoning",
    "vercel:xai/grok-code-fast-1",
    "vercel:xiaomi/mimo-v2-flash",
    "vercel:zai/glm-4.5",
    "vercel:zai/glm-4.5-air",
    "vercel:zai/glm-4.5v",
    "vercel:zai/glm-4.6",
    "vercel:zai/glm-4.6v",
    "vercel:zai/glm-4.6v-flash",
    "vercel:zai/glm-4.7",
    "vivgrid:gpt-5.1-codex",
    "wandb:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "wandb:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "wandb:moonshotai/Kimi-K2-Instruct",
    "xai:grok-4",
    "xai:grok-4-1-fast",
    "xai:grok-4-1-fast-non-reasoning",
    "xai:grok-4-fast",
    "xai:grok-4-fast-non-reasoning",
    "xai:grok-code-fast-1",
    "xiaomi:mimo-v2-flash",
    "zai-coding-plan:glm-4.5",
    "zai-coding-plan:glm-4.5-air",
    "zai-coding-plan:glm-4.5-flash",
    "zai-coding-plan:glm-4.5v",
    "zai-coding-plan:glm-4.6",
    "zai-coding-plan:glm-4.6v",
    "zai-coding-plan:glm-4.7",
    "zai:glm-4.5",
    "zai:glm-4.5-air",
    "zai:glm-4.5-flash",
    "zai:glm-4.5v",
    "zai:glm-4.6",
    "zai:glm-4.6v",
    "zai:glm-4.7",
    "zenmux:anthropic/claude-haiku-4.5",
    "zenmux:anthropic/claude-opus-4",
    "zenmux:anthropic/claude-opus-4.1",
    "zenmux:anthropic/claude-opus-4.5",
    "zenmux:anthropic/claude-sonnet-4",
    "zenmux:anthropic/claude-sonnet-4.5",
    "zenmux:baidu/ernie-5.0-thinking-preview",
    "zenmux:deepseek/deepseek-chat",
    "zenmux:deepseek/deepseek-reasoner",
    "zenmux:deepseek/deepseek-v3.2",
    "zenmux:deepseek/deepseek-v3.2-exp",
    "zenmux:google/gemini-2.5-flash",
    "zenmux:google/gemini-2.5-flash-lite",
    "zenmux:google/gemini-3-flash-preview",
    "zenmux:google/gemini-3-flash-preview-free",
    "zenmux:google/gemini-3-pro-preview",
    "zenmux:inclusionai/ling-1t",
    "zenmux:inclusionai/ring-1t",
    "zenmux:kuaishou/kat-coder-pro-v1",
    "zenmux:kuaishou/kat-coder-pro-v1-free",
    "zenmux:minimax/minimax-m2",
    "zenmux:minimax/minimax-m2.1",
    "zenmux:moonshotai/kimi-k2-0905",
    "zenmux:moonshotai/kimi-k2-thinking",
    "zenmux:moonshotai/kimi-k2-thinking-turbo",
    "zenmux:openai/gpt-5",
    "zenmux:openai/gpt-5-codex",
    "zenmux:openai/gpt-5.1",
    "zenmux:openai/gpt-5.1-chat",
    "zenmux:openai/gpt-5.1-codex",
    "zenmux:openai/gpt-5.1-codex-mini",
    "zenmux:openai/gpt-5.2",
    "zenmux:qwen/qwen3-coder-plus",
    "zenmux:stepfun/step-3",
    "zenmux:volcengine/doubao-seed-1.8",
    "zenmux:volcengine/doubao-seed-code",
    "zenmux:x-ai/grok-4",
    "zenmux:x-ai/grok-4-fast",
    "zenmux:x-ai/grok-4.1-fast",
    "zenmux:x-ai/grok-4.1-fast-non-reasoning",
    "zenmux:x-ai/grok-code-fast-1",
    "zenmux:xiaomi/mimo-v2-flash",
    "zenmux:xiaomi/mimo-v2-flash-free",
    "zenmux:z-ai/glm-4.5",
    "zenmux:z-ai/glm-4.5-air",
    "zenmux:z-ai/glm-4.6",
    "zenmux:z-ai/glm-4.6v",
    "zenmux:z-ai/glm-4.6v-flash",
    "zenmux:z-ai/glm-4.6v-flash-free",
    "zenmux:z-ai/glm-4.7",
    "zhipuai-coding-plan:glm-4.5",
    "zhipuai-coding-plan:glm-4.5-air",
    "zhipuai-coding-plan:glm-4.5-flash",
    "zhipuai-coding-plan:glm-4.5v",
    "zhipuai-coding-plan:glm-4.6",
    "zhipuai-coding-plan:glm-4.6v",
    "zhipuai-coding-plan:glm-4.6v-flash",
    "zhipuai-coding-plan:glm-4.7",
    "zhipuai:glm-4.5",
    "zhipuai:glm-4.5-air",
    "zhipuai:glm-4.5-flash",
    "zhipuai:glm-4.5v",
    "zhipuai:glm-4.6",
    "zhipuai:glm-4.6v",
    "zhipuai:glm-4.6v-flash",
    "zhipuai:glm-4.7",
]

# Model names without provider prefix
ModelsDevModelName = Literal[
    "Qwen/qwen3-coder-480b-a35b-instruct",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1-20250805",
    "claude-opus-4-5-20251101",
    "claude-sonnet-4-5-20250929",
    "gemini-3-flash-preview",
    "gpt-5",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5.1",
    "gpt-5.1-chat-latest",
    "gpt-5.2",
    "gpt-5.2-chat-latest",
    "grok-4-0709",
    "grok-4-1-fast-non-reasoning",
    "grok-4-fast-non-reasoning",
    "grok-code-fast-1",
    "kimi-k2-turbo-preview",
    "openai/gpt-oss-120b",
    "zai-org/glm-4.5",
    "Kimi-K2-0905",
    "claude-haiku-4-5",
    "claude-opus-4-1",
    "claude-opus-4-5",
    "claude-sonnet-4-5",
    "coding-glm-4.7-free",
    "coding-minimax-m2.1-free",
    "deepseek-v3.2",
    "deepseek-v3.2-fast",
    "deepseek-v3.2-speciale",
    "deepseek-v3.2-think",
    "gemini-2.5-flash",
    "gemini-2.5-pro",
    "gemini-3-pro-preview",
    "glm-4.7",
    "gpt-5",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "minimax-m2.1",
    "o4-mini",
    "qwen3-235b-a22b-instruct-2507",
    "qwen3-235b-a22b-thinking-2507",
    "qwen3-coder-480b-a35b-instruct",
    "qwen-deep-research",
    "qwen-doc-turbo",
    "qwen-flash",
    "qwen-mt-plus",
    "qwen-mt-turbo",
    "qwen-plus-character",
    "qwen2-5-14b-instruct",
    "qwen2-5-32b-instruct",
    "qwen2-5-72b-instruct",
    "qwen2-5-7b-instruct",
    "qwen2-5-coder-32b-instruct",
    "qwen2-5-coder-7b-instruct",
    "qwen2-5-math-72b-instruct",
    "qwen2-5-math-7b-instruct",
    "qwen2-5-omni-7b",
    "qwen2-5-vl-72b-instruct",
    "qwen2-5-vl-7b-instruct",
    "qwen3-14b",
    "qwen3-235b-a22b",
    "qwen3-32b",
    "qwen3-8b",
    "qwen3-asr-flash",
    "qwen3-coder-30b-a3b-instruct",
    "qwen3-coder-480b-a35b-instruct",
    "qwen3-coder-flash",
    "qwen3-coder-plus",
    "qwen3-max",
    "qwen3-next-80b-a3b-instruct",
    "qwen3-next-80b-a3b-thinking",
    "qwen3-omni-flash",
    "qwen3-omni-flash-realtime",
    "qwen3-vl-235b-a22b",
    "qwen3-vl-30b-a3b",
    "qwen3-vl-plus",
    "qwq-32b",
    "tongyi-intent-detect-v3",
    "qwen-flash",
    "qwen-mt-plus",
    "qwen-mt-turbo",
    "qwen-plus-character-ja",
    "qwen2-5-14b-instruct",
    "qwen2-5-32b-instruct",
    "qwen2-5-72b-instruct",
    "qwen2-5-7b-instruct",
    "qwen2-5-omni-7b",
    "qwen2-5-vl-72b-instruct",
    "qwen2-5-vl-7b-instruct",
    "qwen3-14b",
    "qwen3-235b-a22b",
    "qwen3-32b",
    "qwen3-8b",
    "qwen3-asr-flash",
    "qwen3-coder-30b-a3b-instruct",
    "qwen3-coder-480b-a35b-instruct",
    "qwen3-coder-flash",
    "qwen3-coder-plus",
    "qwen3-livetranslate-flash-realtime",
    "qwen3-max",
    "qwen3-next-80b-a3b-instruct",
    "qwen3-next-80b-a3b-thinking",
    "qwen3-omni-flash",
    "qwen3-omni-flash-realtime",
    "qwen3-vl-235b-a22b",
    "qwen3-vl-30b-a3b",
    "qwen3-vl-plus",
    "anthropic.claude-haiku-4-5-20251001-v1:0",
    "anthropic.claude-opus-4-1-20250805-v1:0",
    "anthropic.claude-opus-4-5-20251101-v1:0",
    "anthropic.claude-sonnet-4-5-20250929-v1:0",
    "deepseek.v3-v1:0",
    "global.anthropic.claude-opus-4-5-20251101-v1:0",
    "google.gemma-3-27b-it",
    "minimax.minimax-m2",
    "moonshot.kimi-k2-thinking",
    "qwen.qwen3-235b-a22b-2507-v1:0",
    "qwen.qwen3-32b-v1:0",
    "qwen.qwen3-coder-30b-a3b-v1:0",
    "qwen.qwen3-coder-480b-a35b-v1:0",
    "qwen.qwen3-next-80b-a3b",
    "qwen.qwen3-vl-235b-a22b",
    "claude-haiku-4-5",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1",
    "claude-opus-4-1-20250805",
    "claude-opus-4-5",
    "claude-opus-4-5-20251101",
    "claude-sonnet-4-5",
    "claude-sonnet-4-5-20250929",
    "claude-haiku-4-5",
    "claude-opus-4-1",
    "claude-opus-4-5",
    "claude-sonnet-4-5",
    "deepseek-v3.1",
    "deepseek-v3.2",
    "deepseek-v3.2-speciale",
    "gpt-5",
    "gpt-5-chat",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-chat",
    "gpt-5.1-codex",
    "gpt-5.1-codex-mini",
    "gpt-5.2-chat",
    "gpt-5.2-codex",
    "grok-4",
    "grok-4-fast-non-reasoning",
    "grok-4-fast-reasoning",
    "grok-code-fast-1",
    "kimi-k2-thinking",
    "claude-haiku-4-5",
    "claude-opus-4-1",
    "claude-opus-4-5",
    "claude-sonnet-4-5",
    "deepseek-v3.1",
    "deepseek-v3.2",
    "deepseek-v3.2-speciale",
    "gpt-5",
    "gpt-5-chat",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-chat",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-chat",
    "gpt-5.2-codex",
    "grok-4",
    "grok-4-fast-non-reasoning",
    "grok-4-fast-reasoning",
    "grok-code-fast-1",
    "kimi-k2-thinking",
    "Ling-1T",
    "Ring-1T",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "deepseek-ai/DeepSeek-V3.2",
    "moonshotai/Kimi-K2-Instruct-0905",
    "moonshotai/Kimi-K2-Thinking",
    "zai-org/GLM-4.6",
    "zai-org/GLM-4.7",
    "gpt-oss-120b",
    "qwen-3-235b-a22b-instruct-2507",
    "zai-glm-4.7",
    "MiniMaxAI/MiniMax-M2.1-TEE",
    "NousResearch/DeepHermes-3-Mistral-24B-Preview",
    "NousResearch/Hermes-4-14B",
    "NousResearch/Hermes-4-405B-FP8-TEE",
    "NousResearch/Hermes-4-70B",
    "NousResearch/Hermes-4.3-36B",
    "Qwen/Qwen2.5-72B-Instruct",
    "Qwen/Qwen2.5-Coder-32B-Instruct",
    "Qwen/Qwen2.5-VL-32B-Instruct",
    "Qwen/Qwen2.5-VL-72B-Instruct-TEE",
    "Qwen/Qwen3-14B",
    "Qwen/Qwen3-235B-A22B",
    "Qwen/Qwen3-235B-A22B-Instruct-2507-TEE",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-30B-A3B",
    "Qwen/Qwen3-30B-A3B-Instruct-2507",
    "Qwen/Qwen3-32B",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8-TEE",
    "Qwen/Qwen3-Next-80B-A3B-Instruct",
    "Qwen/Qwen3-VL-235B-A22B-Instruct",
    "Qwen/Qwen3Guard-Gen-0.6B",
    "XiaomiMiMo/MiMo-V2-Flash",
    "chutesai/Mistral-Small-3.1-24B-Instruct-2503",
    "chutesai/Mistral-Small-3.2-24B-Instruct-2506",
    "deepseek-ai/DeepSeek-R1-0528-TEE",
    "deepseek-ai/DeepSeek-R1-Distill-Llama-70B",
    "deepseek-ai/DeepSeek-R1-TEE",
    "deepseek-ai/DeepSeek-V3",
    "deepseek-ai/DeepSeek-V3-0324-TEE",
    "deepseek-ai/DeepSeek-V3.1-TEE",
    "deepseek-ai/DeepSeek-V3.1-Terminus-TEE",
    "deepseek-ai/DeepSeek-V3.2-Speciale-TEE",
    "deepseek-ai/DeepSeek-V3.2-TEE",
    "miromind-ai/MiroThinker-v1.5-235B",
    "mistralai/Devstral-2-123B-Instruct-2512",
    "mistralai/Devstral-2-123B-Instruct-2512-TEE",
    "moonshotai/Kimi-K2-Instruct-0905",
    "moonshotai/Kimi-K2-Thinking-TEE",
    "nvidia/NVIDIA-Nemotron-3-Nano-30B-A3B-BF16",
    "openai/gpt-oss-120b-TEE",
    "openai/gpt-oss-20b",
    "rednote-hilab/dots.ocr",
    "tngtech/DeepSeek-R1T-Chimera",
    "tngtech/DeepSeek-TNG-R1T2-Chimera",
    "tngtech/TNG-R1T-Chimera-TEE",
    "unsloth/Mistral-Nemo-Instruct-2407",
    "unsloth/Mistral-Small-24B-Instruct-2501",
    "unsloth/gemma-3-12b-it",
    "unsloth/gemma-3-27b-it",
    "unsloth/gemma-3-4b-it",
    "zai-org/GLM-4.5-Air",
    "zai-org/GLM-4.5-TEE",
    "zai-org/GLM-4.6-TEE",
    "zai-org/GLM-4.6V",
    "zai-org/GLM-4.7-TEE",
    "anthropic/claude-haiku-4-5",
    "anthropic/claude-opus-4-1",
    "anthropic/claude-opus-4-5",
    "anthropic/claude-sonnet-4-5",
    "openai/gpt-5.1",
    "openai/gpt-5.1-codex",
    "openai/gpt-5.2",
    "workers-ai/@cf/ai4bharat/indictrans2-en-indic-1B",
    "workers-ai/@cf/aisingapore/gemma-sea-lion-v4-27b-it",
    "workers-ai/@cf/deepgram/aura-2-en",
    "workers-ai/@cf/deepgram/aura-2-es",
    "workers-ai/@cf/deepgram/nova-3",
    "workers-ai/@cf/ibm-granite/granite-4.0-h-micro",
    "workers-ai/@cf/myshell-ai/melotts",
    "workers-ai/@cf/openai/gpt-oss-120b",
    "workers-ai/@cf/openai/gpt-oss-20b",
    "workers-ai/@cf/pipecat-ai/smart-turn-v2",
    "workers-ai/@cf/qwen/qwen3-30b-a3b-fp8",
    "aura-1",
    "gemma-sea-lion-v4-27b-it",
    "gpt-oss-120b",
    "gpt-oss-20b",
    "granite-4.0-h-micro",
    "lucid-origin",
    "phoenix-1.0",
    "command-a-reasoning-08-2025",
    "command-a-translate-08-2025",
    "command-a-vision-07-2025",
    "claude-4-5-sonnet",
    "devstral-2512",
    "devstral-small-2512",
    "gpt-oss-120b",
    "intellect-3",
    "kimi-k2-instruct",
    "kimi-k2-thinking",
    "qwen3-coder-480b-a35b-instruct",
    "qwen3-next-80b-a3b-thinking",
    "MiniMaxAI/MiniMax-M2",
    "MiniMaxAI/MiniMax-M2.1",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct-Turbo",
    "moonshotai/Kimi-K2-Instruct",
    "moonshotai/Kimi-K2-Thinking",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "zai-org/GLM-4.5",
    "zai-org/GLM-4.7",
    "anthropic/claude-opus-4.1",
    "moonshotai/kimi-k2",
    "openai/gpt-5",
    "openai/gpt-5-mini",
    "openai/gpt-5-nano",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "qwen/qwen3-coder",
    "x-ai/grok-4",
    "accounts/fireworks/models/deepseek-v3p1",
    "accounts/fireworks/models/deepseek-v3p2",
    "accounts/fireworks/models/glm-4p5",
    "accounts/fireworks/models/glm-4p5-air",
    "accounts/fireworks/models/glm-4p6",
    "accounts/fireworks/models/glm-4p7",
    "accounts/fireworks/models/gpt-oss-120b",
    "accounts/fireworks/models/gpt-oss-20b",
    "accounts/fireworks/models/kimi-k2-instruct",
    "accounts/fireworks/models/kimi-k2-thinking",
    "accounts/fireworks/models/minimax-m2",
    "accounts/fireworks/models/minimax-m2p1",
    "accounts/fireworks/models/qwen3-coder-480b-a35b-instruct",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-5",
    "claude-sonnet-4-5-20250929",
    "gemini-2.5-flash",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gpt-5",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5.2",
    "grok-4-fast-non-reasoning",
    "grok-4-fast-reasoning",
    "grok-code-fast-1",
    "LGAI-EXAONE/EXAONE-4.0.1-32B",
    "LGAI-EXAONE/K-EXAONE-236B-A23B",
    "Qwen/Qwen3-235B-A22B-Instruct-2507",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "zai-org/GLM-4.6",
    "claude-haiku-4.5",
    "claude-opus-4.5",
    "claude-opus-41",
    "claude-sonnet-4.5",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gpt-5",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5.1",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-codex",
    "grok-code-fast-1",
    "duo-chat-haiku-4-5",
    "duo-chat-opus-4-5",
    "duo-chat-sonnet-4-5",
    "claude-haiku-4-5@20251001",
    "claude-opus-4-1@20250805",
    "claude-opus-4-5@20251101",
    "claude-sonnet-4-5@20250929",
    "gemini-2.5-flash-lite-preview-09-2025",
    "gemini-2.5-flash-preview-09-2025",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gemini-flash-latest",
    "gemini-flash-lite-latest",
    "openai/gpt-oss-120b-maas",
    "openai/gpt-oss-20b-maas",
    "gemini-2.5-flash-image",
    "gemini-2.5-flash-image-preview",
    "gemini-2.5-flash-lite-preview-09-2025",
    "gemini-2.5-flash-preview-09-2025",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gemini-flash-latest",
    "gemini-flash-lite-latest",
    "gemini-live-2.5-flash",
    "moonshotai/kimi-k2-instruct",
    "moonshotai/kimi-k2-instruct-0905",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "claude-4.5-haiku",
    "claude-4.5-opus",
    "claude-4.5-sonnet",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1",
    "claude-opus-4-1-20250805",
    "claude-sonnet-4-5-20250929",
    "deepseek-v3.1-terminus",
    "deepseek-v3.2",
    "gemini-2.5-flash-lite",
    "gemini-3-pro-preview",
    "grok-4-1-fast-non-reasoning",
    "grok-4-1-fast-reasoning",
    "grok-4-fast-non-reasoning",
    "grok-4-fast-reasoning",
    "kimi-k2-0905",
    "kimi-k2-thinking",
    "qwen3-235b-a22b-thinking",
    "qwen3-coder",
    "qwen3-coder-30b-a3b-instruct",
    "qwen3-vl-235b-a22b-instruct",
    "MiniMaxAI/MiniMax-M2.1",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Thinking",
    "XiaomiMiMo/MiMo-V2-Flash",
    "deepseek-ai/DeepSeek-V3.2",
    "moonshotai/Kimi-K2-Instruct",
    "moonshotai/Kimi-K2-Instruct-0905",
    "moonshotai/Kimi-K2-Thinking",
    "zai-org/GLM-4.7",
    "kimi-k2-0905",
    "kimi-k2-thinking",
    "openai/gpt-oss-20b",
    "qwen/qwen3-30b-a3b-2507",
    "qwen/qwen3-coder-30b",
    "lucidquery-nexus-coder",
    "MiniMax-M2",
    "MiniMax-M2.1",
    "MiniMax-M2",
    "MiniMax-M2.1",
    "devstral-2512",
    "devstral-medium-2507",
    "devstral-medium-latest",
    "devstral-small-2507",
    "labs-devstral-small-2512",
    "mistral-medium-2508",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-30B-A3B-Instruct-2507",
    "Qwen/Qwen3-30B-A3B-Thinking-2507",
    "Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "ZhipuAI/GLM-4.5",
    "ZhipuAI/GLM-4.6",
    "kimi-k2-0711-preview",
    "kimi-k2-0905-preview",
    "kimi-k2-thinking",
    "kimi-k2-thinking-turbo",
    "kimi-k2-turbo-preview",
    "kimi-k2-0711-preview",
    "kimi-k2-0905-preview",
    "kimi-k2-thinking",
    "kimi-k2-thinking-turbo",
    "kimi-k2-turbo-preview",
    "deepseek/deepseek-v3.2:thinking",
    "minimax/minimax-m2.1",
    "mistralai/devstral-2-123b-instruct-2512",
    "mistralai/ministral-14b-instruct-2512",
    "mistralai/mistral-large-3-675b-instruct-2512",
    "nvidia/llama-3_3-nemotron-super-49b-v1_5",
    "zai-org/glm-4.5-air",
    "zai-org/glm-4.7",
    "qwen/qwen3-235b-a22b-instruct-2507",
    "qwen/qwen3-235b-a22b-thinking-2507",
    "qwen/qwen3-coder-480b-a35b-instruct",
    "baichuan/baichuan-m2-32b",
    "baidu/ernie-4.5-21B-a3b-thinking",
    "baidu/ernie-4.5-vl-28b-a3b-thinking",
    "deepseek/deepseek-ocr",
    "deepseek/deepseek-v3.1",
    "deepseek/deepseek-v3.1-terminus",
    "deepseek/deepseek-v3.2",
    "deepseek/deepseek-v3.2-exp",
    "kwaipilot/kat-coder",
    "kwaipilot/kat-coder-pro",
    "minimax/minimax-m2",
    "minimax/minimax-m2.1",
    "moonshotai/kimi-k2-0905",
    "moonshotai/kimi-k2-instruct",
    "moonshotai/kimi-k2-thinking",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "paddlepaddle/paddleocr-vl",
    "qwen/qwen-mt-plus",
    "qwen/qwen3-235b-a22b-instruct-2507",
    "qwen/qwen3-235b-a22b-thinking-2507",
    "qwen/qwen3-coder-30b-a3b-instruct",
    "qwen/qwen3-coder-480b-a35b-instruct",
    "qwen/qwen3-max",
    "qwen/qwen3-next-80b-a3b-instruct",
    "qwen/qwen3-next-80b-a3b-thinking",
    "qwen/qwen3-omni-30b-a3b-instruct",
    "qwen/qwen3-omni-30b-a3b-thinking",
    "qwen/qwen3-vl-235b-a22b-instruct",
    "qwen/qwen3-vl-235b-a22b-thinking",
    "qwen/qwen3-vl-30b-a3b-instruct",
    "qwen/qwen3-vl-30b-a3b-thinking",
    "qwen/qwen3-vl-8b-instruct",
    "skywork/r1v4-lite",
    "xiaomimimo/mimo-v2-flash",
    "zai-org/autoglm-phone-9b-multilingual",
    "zai-org/glm-4.5",
    "zai-org/glm-4.5-air",
    "zai-org/glm-4.5v",
    "zai-org/glm-4.6",
    "zai-org/glm-4.6v",
    "zai-org/glm-4.7",
    "deepseek-ai/deepseek-v3.1",
    "deepseek-ai/deepseek-v3.1-terminus",
    "minimaxai/minimax-m2",
    "mistralai/devstral-2-123b-instruct-2512",
    "mistralai/ministral-14b-instruct-2512",
    "mistralai/mistral-large-3-675b-instruct-2512",
    "moonshotai/kimi-k2-instruct-0905",
    "moonshotai/kimi-k2-thinking",
    "nvidia/nemotron-3-nano-30b-a3b",
    "nvidia/nvidia-nemotron-nano-9b-v2",
    "openai/gpt-oss-120b",
    "qwen/qwen3-coder-480b-a35b-instruct",
    "cogito-2.1:671b-cloud",
    "deepseek-v3.1:671b-cloud",
    "gemini-3-pro-preview:latest",
    "glm-4.6:cloud",
    "gpt-oss:120b-cloud",
    "gpt-oss:20b-cloud",
    "kimi-k2-thinking:cloud",
    "kimi-k2:1t-cloud",
    "minimax-m2:cloud",
    "qwen3-coder:480b-cloud",
    "qwen3-vl-235b-cloud",
    "qwen3-vl-235b-instruct-cloud",
    "gpt-5",
    "gpt-5-chat-latest",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-chat-latest",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-chat-latest",
    "gpt-5.2-codex",
    "gpt-5.2-pro",
    "alpha-glm-4.7",
    "big-pickle",
    "claude-haiku-4-5",
    "claude-opus-4-1",
    "claude-opus-4-5",
    "claude-sonnet-4-5",
    "gemini-3-flash",
    "gemini-3-pro",
    "glm-4.6",
    "glm-4.7-free",
    "gpt-5",
    "gpt-5-codex",
    "gpt-5-nano",
    "gpt-5.1",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-codex",
    "grok-code",
    "kimi-k2",
    "kimi-k2-thinking",
    "minimax-m2.1-free",
    "qwen3-coder",
    "anthropic/claude-haiku-4.5",
    "anthropic/claude-opus-4.1",
    "anthropic/claude-opus-4.5",
    "anthropic/claude-sonnet-4.5",
    "deepseek/deepseek-chat-v3.1",
    "deepseek/deepseek-v3.1-terminus",
    "deepseek/deepseek-v3.1-terminus:exacto",
    "deepseek/deepseek-v3.2",
    "deepseek/deepseek-v3.2-speciale",
    "google/gemini-2.5-flash",
    "google/gemini-2.5-flash-lite-preview-09-2025",
    "google/gemini-2.5-flash-preview-09-2025",
    "google/gemini-3-flash-preview",
    "google/gemini-3-pro-preview",
    "kwaipilot/kat-coder-pro:free",
    "minimax/minimax-m2",
    "minimax/minimax-m2.1",
    "mistralai/codestral-2508",
    "mistralai/devstral-2512",
    "mistralai/devstral-2512:free",
    "mistralai/devstral-medium-2507",
    "mistralai/devstral-small-2507",
    "mistralai/mistral-medium-3.1",
    "moonshotai/kimi-k2",
    "moonshotai/kimi-k2-0905",
    "moonshotai/kimi-k2-0905:exacto",
    "moonshotai/kimi-k2-thinking",
    "moonshotai/kimi-k2:free",
    "nousresearch/hermes-4-405b",
    "nousresearch/hermes-4-70b",
    "nvidia/nemotron-nano-9b-v2",
    "openai/gpt-5",
    "openai/gpt-5-chat",
    "openai/gpt-5-codex",
    "openai/gpt-5-image",
    "openai/gpt-5-mini",
    "openai/gpt-5-nano",
    "openai/gpt-5-pro",
    "openai/gpt-5.1",
    "openai/gpt-5.1-chat",
    "openai/gpt-5.1-codex",
    "openai/gpt-5.1-codex-mini",
    "openai/gpt-5.2",
    "openai/gpt-5.2-chat-latest",
    "openai/gpt-5.2-codex",
    "openai/gpt-5.2-pro",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-120b:exacto",
    "openai/gpt-oss-20b",
    "openai/gpt-oss-safeguard-20b",
    "openrouter/sherlock-dash-alpha",
    "openrouter/sherlock-think-alpha",
    "qwen/qwen3-235b-a22b-thinking-2507",
    "qwen/qwen3-30b-a3b-instruct-2507",
    "qwen/qwen3-30b-a3b-thinking-2507",
    "qwen/qwen3-coder",
    "qwen/qwen3-coder-30b-a3b-instruct",
    "qwen/qwen3-coder-flash",
    "qwen/qwen3-coder:exacto",
    "qwen/qwen3-coder:free",
    "qwen/qwen3-max",
    "qwen/qwen3-next-80b-a3b-instruct",
    "qwen/qwen3-next-80b-a3b-thinking",
    "tngtech/deepseek-r1t2-chimera:free",
    "x-ai/grok-4",
    "x-ai/grok-4-fast",
    "x-ai/grok-4.1-fast",
    "x-ai/grok-code-fast-1",
    "z-ai/glm-4.5",
    "z-ai/glm-4.5-air",
    "z-ai/glm-4.5-air:free",
    "z-ai/glm-4.5v",
    "z-ai/glm-4.6",
    "z-ai/glm-4.6:exacto",
    "z-ai/glm-4.7",
    "gpt-oss-120b",
    "gpt-oss-20b",
    "mistral-small-3.2-24b-instruct-2506",
    "qwen3-32b",
    "qwen3-coder-30b-a3b-instruct",
    "anthropic/claude-haiku-4.5",
    "anthropic/claude-opus-4.1",
    "anthropic/claude-opus-4.5",
    "anthropic/claude-sonnet-4.5",
    "cerebras/gpt-oss-120b-cs",
    "cerebras/zai-glm-4.6-cs",
    "elevenlabs/elevenlabs-music",
    "google/gemini-3-flash",
    "google/gemini-3-pro",
    "google/gemini-deep-research",
    "google/nano-banana",
    "google/nano-banana-pro",
    "google/veo-3-fast",
    "google/veo-3.1",
    "google/veo-3.1-fast",
    "novita/glm-4.6",
    "novita/glm-4.6v",
    "novita/glm-4.7",
    "novita/kat-coder-pro",
    "novita/kimi-k2-thinking",
    "novita/minimax-m2.1",
    "openai/gpt-5",
    "openai/gpt-5-chat",
    "openai/gpt-5-codex",
    "openai/gpt-5-nano",
    "openai/gpt-5-pro",
    "openai/gpt-5.1",
    "openai/gpt-5.1-codex",
    "openai/gpt-5.1-codex-max",
    "openai/gpt-5.1-codex-mini",
    "openai/gpt-5.1-instant",
    "openai/gpt-5.2",
    "openai/gpt-5.2-instant",
    "openai/gpt-5.2-pro",
    "openai/gpt-image-1-mini",
    "openai/gpt-image-1.5",
    "openai/sora-2",
    "openai/sora-2-pro",
    "poetools/claude-code",
    "xai/grok-4",
    "xai/grok-4-fast-non-reasoning",
    "xai/grok-4-fast-reasoning",
    "xai/grok-4.1-fast-non-reasoning",
    "xai/grok-4.1-fast-reasoning",
    "xai/grok-code-fast-1",
    "gpt-oss-120b",
    "qwen3-coder-30b-a3b",
    "anthropic/claude-haiku-4-5",
    "anthropic/claude-opus-4-1",
    "anthropic/claude-opus-4-5",
    "anthropic/claude-sonnet-4-5",
    "google/gemini-3-flash-preview",
    "google/gemini-3-pro-preview",
    "openai/gpt-5",
    "openai/gpt-5-mini",
    "openai/gpt-5-nano",
    "xai/grok-4",
    "xai/grok-4-fast",
    "anthropic--claude-4.5-haiku",
    "anthropic--claude-4.5-opus",
    "anthropic--claude-4.5-sonnet",
    "gpt-5",
    "gpt-5-mini",
    "gpt-5-nano",
    "devstral-2-123b-instruct-2512",
    "qwen3-coder-30b-a3b-instruct",
    "ByteDance-Seed/Seed-OSS-36B-Instruct",
    "Kwaipilot/KAT-Dev",
    "MiniMaxAI/MiniMax-M2",
    "Qwen/Qwen3-235B-A22B-Instruct-2507",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-30B-A3B-Instruct-2507",
    "Qwen/Qwen3-30B-A3B-Thinking-2507",
    "Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Thinking",
    "Qwen/Qwen3-Omni-30B-A3B-Captioner",
    "Qwen/Qwen3-Omni-30B-A3B-Instruct",
    "Qwen/Qwen3-Omni-30B-A3B-Thinking",
    "Qwen/Qwen3-VL-235B-A22B-Instruct",
    "Qwen/Qwen3-VL-235B-A22B-Thinking",
    "Qwen/Qwen3-VL-30B-A3B-Instruct",
    "Qwen/Qwen3-VL-30B-A3B-Thinking",
    "Qwen/Qwen3-VL-32B-Instruct",
    "Qwen/Qwen3-VL-32B-Thinking",
    "Qwen/Qwen3-VL-8B-Instruct",
    "Qwen/Qwen3-VL-8B-Thinking",
    "THUDM/GLM-4.1V-9B-Thinking",
    "deepseek-ai/DeepSeek-V3.1-Terminus",
    "deepseek-ai/DeepSeek-V3.2",
    "inclusionAI/Ling-flash-2.0",
    "inclusionAI/Ling-mini-2.0",
    "inclusionAI/Ring-flash-2.0",
    "moonshotai/Kimi-K2-Instruct",
    "moonshotai/Kimi-K2-Instruct-0905",
    "moonshotai/Kimi-K2-Thinking",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "stepfun-ai/step3",
    "tencent/Hunyuan-MT-7B",
    "zai-org/GLM-4.5",
    "zai-org/GLM-4.5-Air",
    "zai-org/GLM-4.5V",
    "zai-org/GLM-4.6",
    "zai-org/GLM-4.6V",
    "ByteDance-Seed/Seed-OSS-36B-Instruct",
    "MiniMaxAI/MiniMax-M2",
    "Qwen/Qwen3-235B-A22B-Instruct-2507",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-30B-A3B-Instruct-2507",
    "Qwen/Qwen3-30B-A3B-Thinking-2507",
    "Qwen/Qwen3-Coder-30B-A3B-Instruct",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Instruct",
    "Qwen/Qwen3-Next-80B-A3B-Thinking",
    "Qwen/Qwen3-Omni-30B-A3B-Captioner",
    "Qwen/Qwen3-Omni-30B-A3B-Instruct",
    "Qwen/Qwen3-Omni-30B-A3B-Thinking",
    "Qwen/Qwen3-VL-235B-A22B-Instruct",
    "Qwen/Qwen3-VL-235B-A22B-Thinking",
    "Qwen/Qwen3-VL-30B-A3B-Instruct",
    "Qwen/Qwen3-VL-30B-A3B-Thinking",
    "Qwen/Qwen3-VL-32B-Instruct",
    "Qwen/Qwen3-VL-32B-Thinking",
    "Qwen/Qwen3-VL-8B-Instruct",
    "Qwen/Qwen3-VL-8B-Thinking",
    "THUDM/GLM-4.1V-9B-Thinking",
    "deepseek-ai/DeepSeek-V3.1",
    "deepseek-ai/DeepSeek-V3.1-Terminus",
    "deepseek-ai/DeepSeek-V3.2",
    "deepseek-ai/DeepSeek-V3.2-Exp",
    "inclusionAI/Ling-flash-2.0",
    "inclusionAI/Ling-mini-2.0",
    "inclusionAI/Ring-flash-2.0",
    "moonshotai/Kimi-K2-Instruct",
    "moonshotai/Kimi-K2-Instruct-0905",
    "moonshotai/Kimi-K2-Thinking",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "stepfun-ai/step3",
    "tencent/Hunyuan-MT-7B",
    "zai-org/GLM-4.5",
    "zai-org/GLM-4.5-Air",
    "zai-org/GLM-4.5V",
    "zai-org/GLM-4.6",
    "zai-org/GLM-4.6V",
    "zai-org/GLM-4.7",
    "Qwen/Qwen3-235B-A22B-Instruct-2507",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8",
    "deepseek-ai/DeepSeek-R1-0528",
    "deepseek-ai/DeepSeek-V3-0324",
    "deepseek-ai/DeepSeek-V3.1",
    "openai/gpt-oss-120b",
    "zai-org/GLM-4.5-Air",
    "zai-org/GLM-4.5-FP8",
    "hf:MiniMaxAI/MiniMax-M2",
    "hf:MiniMaxAI/MiniMax-M2.1",
    "hf:Qwen/Qwen3-235B-A22B-Thinking-2507",
    "hf:Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "hf:deepseek-ai/DeepSeek-R1-0528",
    "hf:deepseek-ai/DeepSeek-V3-0324",
    "hf:deepseek-ai/DeepSeek-V3.1",
    "hf:deepseek-ai/DeepSeek-V3.1-Terminus",
    "hf:deepseek-ai/DeepSeek-V3.2",
    "hf:moonshotai/Kimi-K2-Instruct-0905",
    "hf:moonshotai/Kimi-K2-Thinking",
    "hf:openai/gpt-oss-120b",
    "hf:zai-org/GLM-4.5",
    "hf:zai-org/GLM-4.6",
    "hf:zai-org/GLM-4.7",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct-FP8",
    "deepseek-ai/DeepSeek-V3-1",
    "essentialai/Rnj-1-Instruct",
    "moonshotai/Kimi-K2-Instruct",
    "moonshotai/Kimi-K2-Thinking",
    "openai/gpt-oss-120b",
    "zai-org/GLM-4.6",
    "solar-pro3",
    "claude-opus-45",
    "deepseek-v3.2",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "google-gemma-3-27b-it",
    "grok-41-fast",
    "grok-code-fast-1",
    "hermes-3-llama-3.1-405b",
    "kimi-k2-thinking",
    "minimax-m21",
    "openai-gpt-52",
    "openai-gpt-oss-120b",
    "zai-org-glm-4.6v",
    "zai-org-glm-4.7",
    "alibaba/qwen-3-14b",
    "alibaba/qwen-3-235b",
    "alibaba/qwen-3-30b",
    "alibaba/qwen-3-32b",
    "alibaba/qwen3-235b-a22b-thinking",
    "alibaba/qwen3-coder",
    "alibaba/qwen3-coder-30b-a3b",
    "alibaba/qwen3-coder-plus",
    "alibaba/qwen3-max",
    "alibaba/qwen3-max-preview",
    "alibaba/qwen3-next-80b-a3b-instruct",
    "alibaba/qwen3-next-80b-a3b-thinking",
    "alibaba/qwen3-vl-instruct",
    "alibaba/qwen3-vl-thinking",
    "anthropic/claude-haiku-4.5",
    "anthropic/claude-opus-4.5",
    "anthropic/claude-sonnet-4.5",
    "arcee-ai/trinity-mini",
    "bfl/flux-kontext-max",
    "bfl/flux-kontext-pro",
    "bfl/flux-pro-1.0-fill",
    "bfl/flux-pro-1.1",
    "bfl/flux-pro-1.1-ultra",
    "bytedance/seed-1.6",
    "bytedance/seed-1.8",
    "deepseek/deepseek-v3.1",
    "deepseek/deepseek-v3.1-terminus",
    "deepseek/deepseek-v3.2",
    "deepseek/deepseek-v3.2-exp",
    "deepseek/deepseek-v3.2-thinking",
    "google/gemini-2.5-flash-lite-preview-09-2025",
    "google/gemini-2.5-flash-preview-09-2025",
    "google/gemini-3-flash",
    "google/gemini-3-pro-image",
    "google/gemini-3-pro-preview",
    "google/imagen-4.0-fast-generate-001",
    "kwaipilot/kat-coder-pro-v1",
    "meituan/longcat-flash-chat",
    "meituan/longcat-flash-thinking",
    "minimax/minimax-m2",
    "minimax/minimax-m2.1",
    "minimax/minimax-m2.1-lightning",
    "mistral/devstral-2",
    "mistral/ministral-14b",
    "mistral/mistral-large-3",
    "moonshotai/kimi-k2",
    "moonshotai/kimi-k2-0905",
    "moonshotai/kimi-k2-thinking",
    "moonshotai/kimi-k2-thinking-turbo",
    "moonshotai/kimi-k2-turbo",
    "nvidia/nemotron-3-nano-30b-a3b",
    "nvidia/nemotron-nano-12b-v2-vl",
    "nvidia/nemotron-nano-9b-v2",
    "openai/gpt-5",
    "openai/gpt-5-chat",
    "openai/gpt-5-codex",
    "openai/gpt-5-mini",
    "openai/gpt-5-nano",
    "openai/gpt-5-pro",
    "openai/gpt-5.1-codex",
    "openai/gpt-5.1-codex-max",
    "openai/gpt-5.1-instant",
    "openai/gpt-5.1-thinking",
    "openai/gpt-5.2",
    "openai/gpt-5.2-chat",
    "openai/gpt-5.2-codex",
    "openai/gpt-5.2-pro",
    "openai/gpt-oss-120b",
    "openai/gpt-oss-20b",
    "prime-intellect/intellect-3",
    "recraft/recraft-v2",
    "recraft/recraft-v3",
    "voyage/voyage-3-large",
    "voyage/voyage-code-2",
    "voyage/voyage-code-3",
    "voyage/voyage-finance-2",
    "voyage/voyage-law-2",
    "xai/grok-4",
    "xai/grok-4-fast-non-reasoning",
    "xai/grok-4-fast-reasoning",
    "xai/grok-4.1-fast-non-reasoning",
    "xai/grok-4.1-fast-reasoning",
    "xai/grok-code-fast-1",
    "xiaomi/mimo-v2-flash",
    "zai/glm-4.5",
    "zai/glm-4.5-air",
    "zai/glm-4.5v",
    "zai/glm-4.6",
    "zai/glm-4.6v",
    "zai/glm-4.6v-flash",
    "zai/glm-4.7",
    "gpt-5.1-codex",
    "Qwen/Qwen3-235B-A22B-Thinking-2507",
    "Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "moonshotai/Kimi-K2-Instruct",
    "grok-4",
    "grok-4-1-fast",
    "grok-4-1-fast-non-reasoning",
    "grok-4-fast",
    "grok-4-fast-non-reasoning",
    "grok-code-fast-1",
    "mimo-v2-flash",
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.7",
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.7",
    "anthropic/claude-haiku-4.5",
    "anthropic/claude-opus-4",
    "anthropic/claude-opus-4.1",
    "anthropic/claude-opus-4.5",
    "anthropic/claude-sonnet-4",
    "anthropic/claude-sonnet-4.5",
    "baidu/ernie-5.0-thinking-preview",
    "deepseek/deepseek-chat",
    "deepseek/deepseek-reasoner",
    "deepseek/deepseek-v3.2",
    "deepseek/deepseek-v3.2-exp",
    "google/gemini-2.5-flash",
    "google/gemini-2.5-flash-lite",
    "google/gemini-3-flash-preview",
    "google/gemini-3-flash-preview-free",
    "google/gemini-3-pro-preview",
    "inclusionai/ling-1t",
    "inclusionai/ring-1t",
    "kuaishou/kat-coder-pro-v1",
    "kuaishou/kat-coder-pro-v1-free",
    "minimax/minimax-m2",
    "minimax/minimax-m2.1",
    "moonshotai/kimi-k2-0905",
    "moonshotai/kimi-k2-thinking",
    "moonshotai/kimi-k2-thinking-turbo",
    "openai/gpt-5",
    "openai/gpt-5-codex",
    "openai/gpt-5.1",
    "openai/gpt-5.1-chat",
    "openai/gpt-5.1-codex",
    "openai/gpt-5.1-codex-mini",
    "openai/gpt-5.2",
    "qwen/qwen3-coder-plus",
    "stepfun/step-3",
    "volcengine/doubao-seed-1.8",
    "volcengine/doubao-seed-code",
    "x-ai/grok-4",
    "x-ai/grok-4-fast",
    "x-ai/grok-4.1-fast",
    "x-ai/grok-4.1-fast-non-reasoning",
    "x-ai/grok-code-fast-1",
    "xiaomi/mimo-v2-flash",
    "xiaomi/mimo-v2-flash-free",
    "z-ai/glm-4.5",
    "z-ai/glm-4.5-air",
    "z-ai/glm-4.6",
    "z-ai/glm-4.6v",
    "z-ai/glm-4.6v-flash",
    "z-ai/glm-4.6v-flash-free",
    "z-ai/glm-4.7",
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.6v-flash",
    "glm-4.7",
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.6v-flash",
    "glm-4.7",
]

__all__ = ["ModelsDevModelId", "ModelsDevModelName"]



"""Generated model names for anthropic-max provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 8
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
AnthropicMaxModelId = Literal[
    "anthropic-max:claude-haiku-4-5",
    "anthropic-max:claude-haiku-4-5-20251001",
    "anthropic-max:claude-opus-4-1",
    "anthropic-max:claude-opus-4-1-20250805",
    "anthropic-max:claude-opus-4-5",
    "anthropic-max:claude-opus-4-5-20251101",
    "anthropic-max:claude-sonnet-4-5",
    "anthropic-max:claude-sonnet-4-5-20250929",
]

# Model names without provider prefix
AnthropicMaxModelName = Literal[
    "claude-haiku-4-5",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1",
    "claude-opus-4-1-20250805",
    "claude-opus-4-5",
    "claude-opus-4-5-20251101",
    "claude-sonnet-4-5",
    "claude-sonnet-4-5-20250929",
]

__all__ = ["AnthropicMaxModelId", "AnthropicMaxModelName"]



"""Thinking/reasoning level configuration for different model providers.

This module provides functions to discover and configure thinking/reasoning levels
for models that support extended thinking capabilities.

Pydantic-ai uses provider-prefixed settings names:
- Anthropic: `anthropic_thinking`
- OpenAI: `openai_reasoning_effort`, `openai_reasoning_summary`
- Google: `google_thinking_config`
"""

from __future__ import annotations

from typing import Any, Literal


ReasoningLevel = Literal["off", "minimal", "low", "medium", "high", "max"]


def supports_reasoning(provider: str, model_id: str) -> bool:
    """Check if a model supports configurable reasoning/thinking levels.

    Args:
        provider: Provider name (e.g., "anthropic", "openai", "google")
        model_id: Model identifier

    Returns:
        True if the model supports configurable reasoning levels.
    """
    model_id_lower = model_id.lower()

    # Models with reasoning capability but no configurable variants
    if any(x in model_id_lower for x in ("deepseek", "minimax", "glm", "mistral")):
        return False

    # OpenAI o1-mini doesn't support reasoning effort
    if provider == "openai" and model_id_lower == "o1-mini":
        return False

    # Supported providers (pydantic-ai and models.dev provider names)
    supported_providers = {
        "anthropic",
        "openai",
        "azure",
        "google",
        "google-gla",
        "google-vertex",
        "bedrock",
        "amazon-bedrock",
    }

    return provider in supported_providers


def get_reasoning_levels(provider: str, model_id: str) -> list[str]:  # noqa: PLR0911
    """Get available reasoning levels for a model.

    Args:
        provider: Provider name (e.g., "anthropic", "openai", "google")
        model_id: Model identifier

    Returns:
        List of available level names, empty if reasoning not supported.
    """
    if not supports_reasoning(provider, model_id):
        return []

    model_id_lower = model_id.lower()

    # Anthropic models (native or via Bedrock)
    if provider == "anthropic":
        return ["off", "high", "max"]

    # AWS Bedrock with Anthropic models
    if provider in ("bedrock", "amazon-bedrock"):
        if "anthropic" in model_id_lower or "claude" in model_id_lower:
            return ["off", "high", "max"]
        return []

    # OpenAI models
    if provider in ("openai", "azure"):
        levels = ["off", "low", "medium", "high"]
        if "gpt-5" in model_id_lower:
            levels.insert(1, "minimal")  # after "off"
        return levels

    # Google models
    if provider in ("google", "google-gla", "google-vertex"):
        if "2.5" in model_id_lower or "2-5" in model_id_lower:
            return ["off", "high", "max"]
        return ["off", "low", "high"]

    return []


def get_reasoning_settings(provider: str, model_id: str, level: str) -> dict[str, Any]:  # noqa: PLR0911
    """Get pydantic-ai ModelSettings for a reasoning level.

    Args:
        provider: Provider name (e.g., "anthropic", "openai", "google")
        model_id: Model identifier
        level: Reasoning level (e.g., "high", "max", "low", "medium")

    Returns:
        Dict of pydantic-ai ModelSettings for the specified level.

    Raises:
        ValueError: If level is not valid for this provider/model.
    """
    available = get_reasoning_levels(provider, model_id)
    if not available:
        msg = f"Model {provider}:{model_id} does not support configurable reasoning"
        raise ValueError(msg)

    if level not in available:
        msg = f"Invalid level '{level}' for {provider}:{model_id}. Available: {available}"
        raise ValueError(msg)

    model_id_lower = model_id.lower()

    # Anthropic models (native or via Bedrock)
    if provider == "anthropic":
        if level == "off":
            return {"anthropic_thinking": {"type": "disabled"}}
        budgets = {"high": 16000, "max": 31999}
        return {"anthropic_thinking": {"type": "enabled", "budget_tokens": budgets[level]}}

    # AWS Bedrock with Anthropic models
    if provider in ("bedrock", "amazon-bedrock") and (
        "anthropic" in model_id_lower or "claude" in model_id_lower
    ):
        if level == "off":
            return {"anthropic_thinking": {"type": "disabled"}}
        budgets = {"high": 16000, "max": 31999}
        return {"anthropic_thinking": {"type": "enabled", "budget_tokens": budgets[level]}}

    # OpenAI models
    if provider in ("openai", "azure"):
        if level == "off":
            return {}  # No reasoning settings = disabled
        return {
            "openai_reasoning_effort": level,
            "openai_reasoning_summary": "auto",
        }

    # Google models
    if provider in ("google", "google-gla", "google-vertex"):
        if level == "off":
            return {"google_thinking_config": {"include_thoughts": False}}
        if "2.5" in model_id_lower or "2-5" in model_id_lower:
            budgets = {"high": 16000, "max": 24576}
            return {
                "google_thinking_config": {
                    "include_thoughts": True,
                    "thinking_budget": budgets[level],
                }
            }
        # Gemini 3+ just enables thinking, level doesn't map to budget
        return {"google_thinking_config": {"include_thoughts": True}}

    # Should not reach here if supports_reasoning is correct
    msg = f"No settings implementation for {provider}:{model_id}"
    raise ValueError(msg)


# Keep the old function for backwards compatibility with ModelInfo.pydantic_ai_variants
def get_pydantic_ai_variants(
    provider: str,
    model_id: str,
    supports_reasoning_flag: bool,
) -> dict[str, dict[str, Any]]:
    """Generate thinking level variants based on provider and model capabilities.

    Args:
        provider: Provider name (e.g., "anthropic", "openai", "google")
        model_id: Model identifier
        supports_reasoning_flag: Whether the model supports reasoning/thinking
            (from models.dev metadata)

    Returns:
        Dict mapping variant name to pydantic-ai ModelSettings.
        Empty dict if model doesn't support reasoning.
    """
    if not supports_reasoning_flag:
        return {}

    levels = get_reasoning_levels(provider, model_id)
    if not levels:
        return {}

    return {level: get_reasoning_settings(provider, model_id, level) for level in levels}



"""Generated model names for anthropic provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 8
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
AnthropicModelId = Literal[
    "anthropic:claude-haiku-4-5",
    "anthropic:claude-haiku-4-5-20251001",
    "anthropic:claude-opus-4-1",
    "anthropic:claude-opus-4-1-20250805",
    "anthropic:claude-opus-4-5",
    "anthropic:claude-opus-4-5-20251101",
    "anthropic:claude-sonnet-4-5",
    "anthropic:claude-sonnet-4-5-20250929",
]

# Model names without provider prefix
AnthropicModelName = Literal[
    "claude-haiku-4-5",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1",
    "claude-opus-4-1-20250805",
    "claude-opus-4-5",
    "claude-opus-4-5-20251101",
    "claude-sonnet-4-5",
    "claude-sonnet-4-5-20250929",
]

__all__ = ["AnthropicModelId", "AnthropicModelName"]



"""Claude Code provider with static model definitions."""

from __future__ import annotations

from typing import Any

from tokonomics.model_discovery.base import ModelProvider
from tokonomics.model_discovery.model_info import ModelInfo, ModelPricing


CLAUDE_CODE_MODELS: list[ModelInfo] = [
    ModelInfo(
        id="sonnet",
        name="Claude Sonnet (Claude Code)",
        provider="claude-code",
        description="Latest Claude Sonnet model - balanced performance and speed",
        owned_by="anthropic",
        context_window=200000,
        max_output_tokens=8192,
        input_modalities={"text", "image", "file"},
        output_modalities={"text"},
        pricing=ModelPricing(
            prompt=3.0 / 1_000_000,
            completion=15.0 / 1_000_000,
            input_cache_read=0.30 / 1_000_000,
            input_cache_write=3.75 / 1_000_000,
        ),
    ),
    ModelInfo(
        id="haiku",
        name="Claude Haiku (Claude Code)",
        provider="claude-code",
        description="Latest Claude Haiku model - fast and cost-effective",
        owned_by="anthropic",
        context_window=200000,
        max_output_tokens=8192,
        input_modalities={"text", "image", "file"},
        output_modalities={"text"},
        pricing=ModelPricing(
            prompt=0.80 / 1_000_000,
            completion=4.0 / 1_000_000,
            input_cache_read=0.08 / 1_000_000,
            input_cache_write=1.0 / 1_000_000,
        ),
    ),
    ModelInfo(
        id="opus",
        name="Claude Opus (Claude Code)",
        provider="claude-code",
        description="Latest Claude Opus model - most capable",
        owned_by="anthropic",
        context_window=200000,
        max_output_tokens=64000,
        input_modalities={"text", "image", "file"},
        output_modalities={"text"},
        pricing=ModelPricing(
            prompt=5.0 / 1_000_000,
            completion=25.0 / 1_000_000,
            input_cache_read=0.50 / 1_000_000,
            input_cache_write=6.25 / 1_000_000,
        ),
    ),
]


class ClaudeCodeProvider(ModelProvider):
    """Static provider for Claude Code models."""

    def __init__(self) -> None:
        super().__init__()
        self.base_url = ""
        self.headers = {}
        self.params = {}

    def is_available(self) -> bool:
        """Always available - no external dependencies."""
        return True

    def _parse_model(self, data: dict[str, Any]) -> ModelInfo:
        """Not used for static provider."""
        raise NotImplementedError

    async def get_models(self) -> list[ModelInfo]:
        """Return static list of Claude Code models."""
        return CLAUDE_CODE_MODELS.copy()



"""Generated model names from all providers.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total providers: 18
"""

from __future__ import annotations


from .anthropic import AnthropicModelId, AnthropicModelName
from .anthropic_max import AnthropicMaxModelId, AnthropicMaxModelName
from .cerebras import CerebrasModelId, CerebrasModelName
from .claude_code import ClaudeCodeModelId, ClaudeCodeModelName
from .cohere import CohereModelId, CohereModelName
from .copilot import CopilotModelId, CopilotModelName
from .deepseek import DeepseekModelId, DeepseekModelName
from .gemini import GeminiModelId, GeminiModelName
from .github import GithubModelId, GithubModelName
from .groq import GroqModelId, GroqModelName
from .mistral import MistralModelId, MistralModelName
from .moonshotai import MoonshotaiModelId, MoonshotaiModelName
from .openai import OpenaiModelId, OpenaiModelName
from .openrouter import OpenrouterModelId, OpenrouterModelName
from .requesty import RequestyModelId, RequestyModelName
from .vercel_gateway import VercelGatewayModelId, VercelGatewayModelName
from .xai import XaiModelId, XaiModelName
from .zai import ZaiModelId, ZaiModelName

# models.dev aggregator (not included in ModelId/ModelName unions)
from .modelsdev import ModelsDevModelId, ModelsDevModelName

# Union of all provider model IDs (fully-qualified provider:model format)
# Total: 682, Unique: 682
ModelId = (
    AnthropicModelId
    | AnthropicMaxModelId
    | CerebrasModelId
    | ClaudeCodeModelId
    | CohereModelId
    | CopilotModelId
    | DeepseekModelId
    | GeminiModelId
    | GithubModelId
    | GroqModelId
    | MistralModelId
    | MoonshotaiModelId
    | OpenaiModelId
    | OpenrouterModelId
    | RequestyModelId
    | VercelGatewayModelId
    | XaiModelId
    | ZaiModelId
)

# Union of all provider model names (without provider prefix)
# Total: 682, Unique: 587 (duplicates exist across providers)
ModelName = (
    AnthropicModelName
    | AnthropicMaxModelName
    | CerebrasModelName
    | ClaudeCodeModelName
    | CohereModelName
    | CopilotModelName
    | DeepseekModelName
    | GeminiModelName
    | GithubModelName
    | GroqModelName
    | MistralModelName
    | MoonshotaiModelName
    | OpenaiModelName
    | OpenrouterModelName
    | RequestyModelName
    | VercelGatewayModelName
    | XaiModelName
    | ZaiModelName
)

__all__ = [
    "AnthropicMaxModelId",
    "AnthropicMaxModelName",
    "AnthropicModelId",
    "AnthropicModelName",
    "CerebrasModelId",
    "CerebrasModelName",
    "ClaudeCodeModelId",
    "ClaudeCodeModelName",
    "CohereModelId",
    "CohereModelName",
    "CopilotModelId",
    "CopilotModelName",
    "DeepseekModelId",
    "DeepseekModelName",
    "GeminiModelId",
    "GeminiModelName",
    "GithubModelId",
    "GithubModelName",
    "GroqModelId",
    "GroqModelName",
    "MistralModelId",
    "MistralModelName",
    "ModelId",
    "ModelName",
    "ModelsDevModelId",
    "ModelsDevModelName",
    "MoonshotaiModelId",
    "MoonshotaiModelName",
    "OpenaiModelId",
    "OpenaiModelName",
    "OpenrouterModelId",
    "OpenrouterModelName",
    "RequestyModelId",
    "RequestyModelName",
    "VercelGatewayModelId",
    "VercelGatewayModelName",
    "XaiModelId",
    "XaiModelName",
    "ZaiModelId",
    "ZaiModelName",
]



"""Generated model names for claude-code provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 3
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
ClaudeCodeModelId = Literal[
    "claude-code:haiku",
    "claude-code:opus",
    "claude-code:sonnet",
]

# Model names without provider prefix
ClaudeCodeModelName = Literal[
    "haiku",
    "opus",
    "sonnet",
]

__all__ = ["ClaudeCodeModelId", "ClaudeCodeModelName"]



"""Comet API provider."""

from __future__ import annotations

import contextlib
from datetime import datetime
import os
from typing import Any

from tokonomics.model_discovery.base import ModelProvider
from tokonomics.model_discovery.model_info import ModelInfo


class CometProvider(ModelProvider):
    """Comet API provider."""

    def __init__(self, api_key: str | None = None):
        super().__init__()
        self.api_key = api_key or os.environ.get("COMET_API_KEY")
        if not self.api_key:
            msg = "Comet API key not found in parameters or COMET_API_KEY env var"
            raise RuntimeError(msg)

        self.base_url = "https://api.cometapi.com/v1"
        self.headers = {"Authorization": f"Bearer {self.api_key}"}
        self.params = {}

    def is_available(self) -> bool:
        """Check whether the provider is available for use."""
        return bool(self.api_key)

    def _parse_model(self, data: dict[str, Any]) -> ModelInfo:
        """Parse Comet API response into ModelInfo."""
        # Parse created timestamp
        created_at = None
        if created_timestamp := data.get("created"):
            with contextlib.suppress(ValueError, TypeError, OverflowError):
                created_at = datetime.fromtimestamp(created_timestamp)

        return ModelInfo(
            id=str(data["id"]),
            name=str(data.get("id")),  # Use id as name since no separate name field
            provider="comet",
            owned_by=str(data.get("owned_by")) if data.get("owned_by") else None,
            is_embedding="embedding" in str(data.get("id", "")).lower(),
            created_at=created_at,
            metadata={
                "object": data.get("object"),
                "root": data.get("root"),
                "parent": data.get("parent"),
                "permissions": data.get("permission", []),
            },
        )


if __name__ == "__main__":
    import asyncio

    provider = CometProvider()
    models = asyncio.run(provider.get_models())
    for model in models:
        print(model.format())



"""Generated model names for cerebras provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 3
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
CerebrasModelId = Literal[
    "cerebras:gpt-oss-120b",
    "cerebras:qwen-3-235b-a22b-instruct-2507",
    "cerebras:zai-glm-4.7",
]

# Model names without provider prefix
CerebrasModelName = Literal[
    "gpt-oss-120b",
    "qwen-3-235b-a22b-instruct-2507",
    "zai-glm-4.7",
]

__all__ = ["CerebrasModelId", "CerebrasModelName"]



"""Generated model names for copilot provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 20
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
CopilotModelId = Literal[
    "copilot:claude-haiku-4.5",
    "copilot:claude-opus-4.5",
    "copilot:claude-sonnet-4",
    "copilot:claude-sonnet-4.5",
    "copilot:gemini-2.5-pro",
    "copilot:gemini-3-flash-preview",
    "copilot:gemini-3-pro-preview",
    "copilot:gpt-4.1",
    "copilot:gpt-4o",
    "copilot:gpt-5",
    "copilot:gpt-5-codex",
    "copilot:gpt-5-mini",
    "copilot:gpt-5.1",
    "copilot:gpt-5.1-codex",
    "copilot:gpt-5.1-codex-max",
    "copilot:gpt-5.1-codex-mini",
    "copilot:gpt-5.2",
    "copilot:gpt-5.2-codex",
    "copilot:grok-code-fast-1",
    "copilot:oswe-vscode-prime",
]

# Model names without provider prefix
CopilotModelName = Literal[
    "claude-haiku-4.5",
    "claude-opus-4.5",
    "claude-sonnet-4",
    "claude-sonnet-4.5",
    "gemini-2.5-pro",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gpt-4.1",
    "gpt-4o",
    "gpt-5",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5.1",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-codex",
    "grok-code-fast-1",
    "oswe-vscode-prime",
]

__all__ = ["CopilotModelId", "CopilotModelName"]



"""Generated model names for cohere provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 3
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
CohereModelId = Literal[
    "cohere:command-a-reasoning-08-2025",
    "cohere:command-a-translate-08-2025",
    "cohere:command-a-vision-07-2025",
]

# Model names without provider prefix
CohereModelName = Literal[
    "command-a-reasoning-08-2025",
    "command-a-translate-08-2025",
    "command-a-vision-07-2025",
]

__all__ = ["CohereModelId", "CohereModelName"]



"""Generated model names for openai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 15
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
OpenaiModelId = Literal[
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:gpt-5.1-chat-latest",
    "openai:gpt-5.1-codex",
    "openai:gpt-5.1-codex-max",
    "openai:gpt-5.1-codex-mini",
    "openai:gpt-5.2",
    "openai:gpt-5.2-chat-latest",
    "openai:gpt-5.2-codex",
    "openai:gpt-5.2-pro",
]

# Model names without provider prefix
OpenaiModelName = Literal[
    "gpt-5",
    "gpt-5-chat-latest",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-chat-latest",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-chat-latest",
    "gpt-5.2-codex",
    "gpt-5.2-pro",
]

__all__ = ["OpenaiModelId", "OpenaiModelName"]



"""Generated model names for zai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 7
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
ZaiModelId = Literal[
    "zai:glm-4.5",
    "zai:glm-4.5-air",
    "zai:glm-4.5-flash",
    "zai:glm-4.5v",
    "zai:glm-4.6",
    "zai:glm-4.6v",
    "zai:glm-4.7",
]

# Model names without provider prefix
ZaiModelName = Literal[
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.7",
]

__all__ = ["ZaiModelId", "ZaiModelName"]
